@@ -1,10 +1,225 @@
-      SUBROUTINE SGESDD( JOBZ, M, N, A, LDA, S, U, LDU, VT, LDVT,
-     $                   WORK, LWORK, IWORK, INFO )
+*> \brief \b SGESDD
 *
-*  -- LAPACK driver routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*> \htmlonly
+*> Download SGESDD + dependencies 
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/sgesdd.f"> 
+*> [TGZ]</a> 
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/sgesdd.f"> 
+*> [ZIP]</a> 
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/sgesdd.f"> 
+*> [TXT]</a>
+*> \endhtmlonly 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SGESDD( JOBZ, M, N, A, LDA, S, U, LDU, VT, LDVT, WORK,
+*                          LWORK, IWORK, INFO )
+* 
+*       .. Scalar Arguments ..
+*       CHARACTER          JOBZ
+*       INTEGER            INFO, LDA, LDU, LDVT, LWORK, M, N
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            IWORK( * )
+*       REAL               A( LDA, * ), S( * ), U( LDU, * ),
+*      $                   VT( LDVT, * ), WORK( * )
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SGESDD computes the singular value decomposition (SVD) of a real
+*> M-by-N matrix A, optionally computing the left and right singular
+*> vectors.  If singular vectors are desired, it uses a
+*> divide-and-conquer algorithm.
+*>
+*> The SVD is written
+*>
+*>      A = U * SIGMA * transpose(V)
+*>
+*> where SIGMA is an M-by-N matrix which is zero except for its
+*> min(m,n) diagonal elements, U is an M-by-M orthogonal matrix, and
+*> V is an N-by-N orthogonal matrix.  The diagonal elements of SIGMA
+*> are the singular values of A; they are real and non-negative, and
+*> are returned in descending order.  The first min(m,n) columns of
+*> U and V are the left and right singular vectors of A.
+*>
+*> Note that the routine returns VT = V**T, not V.
+*>
+*> The divide and conquer algorithm makes very mild assumptions about
+*> floating point arithmetic. It will work on machines with a guard
+*> digit in add/subtract, or on those binary machines without guard
+*> digits which subtract like the Cray X-MP, Cray Y-MP, Cray C-90, or
+*> Cray-2. It could conceivably fail on hexadecimal or decimal machines
+*> without guard digits, but we know of none.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] JOBZ
+*> \verbatim
+*>          JOBZ is CHARACTER*1
+*>          Specifies options for computing all or part of the matrix U:
+*>          = 'A':  all M columns of U and all N rows of V**T are
+*>                  returned in the arrays U and VT;
+*>          = 'S':  the first min(M,N) columns of U and the first
+*>                  min(M,N) rows of V**T are returned in the arrays U
+*>                  and VT;
+*>          = 'O':  If M >= N, the first N columns of U are overwritten
+*>                  on the array A and all rows of V**T are returned in
+*>                  the array VT;
+*>                  otherwise, all columns of U are returned in the
+*>                  array U and the first M rows of V**T are overwritten
+*>                  in the array A;
+*>          = 'N':  no columns of U or rows of V**T are computed.
+*> \endverbatim
+*>
+*> \param[in] M
+*> \verbatim
+*>          M is INTEGER
+*>          The number of rows of the input matrix A.  M >= 0.
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>          The number of columns of the input matrix A.  N >= 0.
+*> \endverbatim
+*>
+*> \param[in,out] A
+*> \verbatim
+*>          A is REAL array, dimension (LDA,N)
+*>          On entry, the M-by-N matrix A.
+*>          On exit,
+*>          if JOBZ = 'O',  A is overwritten with the first N columns
+*>                          of U (the left singular vectors, stored
+*>                          columnwise) if M >= N;
+*>                          A is overwritten with the first M rows
+*>                          of V**T (the right singular vectors, stored
+*>                          rowwise) otherwise.
+*>          if JOBZ .ne. 'O', the contents of A are destroyed.
+*> \endverbatim
+*>
+*> \param[in] LDA
+*> \verbatim
+*>          LDA is INTEGER
+*>          The leading dimension of the array A.  LDA >= max(1,M).
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is REAL array, dimension (min(M,N))
+*>          The singular values of A, sorted so that S(i) >= S(i+1).
+*> \endverbatim
+*>
+*> \param[out] U
+*> \verbatim
+*>          U is REAL array, dimension (LDU,UCOL)
+*>          UCOL = M if JOBZ = 'A' or JOBZ = 'O' and M < N;
+*>          UCOL = min(M,N) if JOBZ = 'S'.
+*>          If JOBZ = 'A' or JOBZ = 'O' and M < N, U contains the M-by-M
+*>          orthogonal matrix U;
+*>          if JOBZ = 'S', U contains the first min(M,N) columns of U
+*>          (the left singular vectors, stored columnwise);
+*>          if JOBZ = 'O' and M >= N, or JOBZ = 'N', U is not referenced.
+*> \endverbatim
+*>
+*> \param[in] LDU
+*> \verbatim
+*>          LDU is INTEGER
+*>          The leading dimension of the array U.  LDU >= 1; if
+*>          JOBZ = 'S' or 'A' or JOBZ = 'O' and M < N, LDU >= M.
+*> \endverbatim
+*>
+*> \param[out] VT
+*> \verbatim
+*>          VT is REAL array, dimension (LDVT,N)
+*>          If JOBZ = 'A' or JOBZ = 'O' and M >= N, VT contains the
+*>          N-by-N orthogonal matrix V**T;
+*>          if JOBZ = 'S', VT contains the first min(M,N) rows of
+*>          V**T (the right singular vectors, stored rowwise);
+*>          if JOBZ = 'O' and M < N, or JOBZ = 'N', VT is not referenced.
+*> \endverbatim
+*>
+*> \param[in] LDVT
+*> \verbatim
+*>          LDVT is INTEGER
+*>          The leading dimension of the array VT.  LDVT >= 1; if
+*>          JOBZ = 'A' or JOBZ = 'O' and M >= N, LDVT >= N;
+*>          if JOBZ = 'S', LDVT >= min(M,N).
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension (MAX(1,LWORK))
+*>          On exit, if INFO = 0, WORK(1) returns the optimal LWORK;
+*> \endverbatim
+*>
+*> \param[in] LWORK
+*> \verbatim
+*>          LWORK is INTEGER
+*>          The dimension of the array WORK. LWORK >= 1.
+*>          If JOBZ = 'N',
+*>            LWORK >= 3*min(M,N) + max(max(M,N),6*min(M,N)).
+*>          If JOBZ = 'O',
+*>            LWORK >= 3*min(M,N) + 
+*>                     max(max(M,N),5*min(M,N)*min(M,N)+4*min(M,N)).
+*>          If JOBZ = 'S' or 'A'
+*>            LWORK >= min(M,N)*(7+4*min(M,N))
+*>          For good performance, LWORK should generally be larger.
+*>          If LWORK = -1 but other input arguments are legal, WORK(1)
+*>          returns the optimal LWORK.
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (8*min(M,N))
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          = 0:  successful exit.
+*>          < 0:  if INFO = -i, the i-th argument had an illegal value.
+*>          > 0:  SBDSDC did not converge, updating process failed.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2015
+*
+*> \ingroup realGEsing
+*
+*> \par Contributors:
+*  ==================
+*>
+*>     Ming Gu and Huan Ren, Computer Science Division, University of
+*>     California at Berkeley, USA
+*>
+*  =====================================================================
+      SUBROUTINE SGESDD( JOBZ, M, N, A, LDA, S, U, LDU, VT, LDVT, WORK,
+     $                   LWORK, IWORK, INFO )
+*
+*  -- LAPACK driver routine (version 3.6.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBZ
@@ -16,145 +231,18 @@
      $                   VT( LDVT, * ), WORK( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SGESDD computes the singular value decomposition (SVD) of a real
-*  M-by-N matrix A, optionally computing the left and right singular
-*  vectors.  If singular vectors are desired, it uses a
-*  divide-and-conquer algorithm.
-*
-*  The SVD is written
-*
-*       A = U * SIGMA * transpose(V)
-*
-*  where SIGMA is an M-by-N matrix which is zero except for its
-*  min(m,n) diagonal elements, U is an M-by-M orthogonal matrix, and
-*  V is an N-by-N orthogonal matrix.  The diagonal elements of SIGMA
-*  are the singular values of A; they are real and non-negative, and
-*  are returned in descending order.  The first min(m,n) columns of
-*  U and V are the left and right singular vectors of A.
-*
-*  Note that the routine returns VT = V**T, not V.
-*
-*  The divide and conquer algorithm makes very mild assumptions about
-*  floating point arithmetic. It will work on machines with a guard
-*  digit in add/subtract, or on those binary machines without guard
-*  digits which subtract like the Cray X-MP, Cray Y-MP, Cray C-90, or
-*  Cray-2. It could conceivably fail on hexadecimal or decimal machines
-*  without guard digits, but we know of none.
-*
-*  Arguments
-*  =========
-*
-*  JOBZ    (input) CHARACTER*1
-*          Specifies options for computing all or part of the matrix U:
-*          = 'A':  all M columns of U and all N rows of V**T are
-*                  returned in the arrays U and VT;
-*          = 'S':  the first min(M,N) columns of U and the first
-*                  min(M,N) rows of V**T are returned in the arrays U
-*                  and VT;
-*          = 'O':  If M >= N, the first N columns of U are overwritten
-*                  on the array A and all rows of V**T are returned in
-*                  the array VT;
-*                  otherwise, all columns of U are returned in the
-*                  array U and the first M rows of V**T are overwritten
-*                  in the array VT;
-*          = 'N':  no columns of U or rows of V**T are computed.
-*
-*  M       (input) INTEGER
-*          The number of rows of the input matrix A.  M >= 0.
-*
-*  N       (input) INTEGER
-*          The number of columns of the input matrix A.  N >= 0.
-*
-*  A       (input/output) REAL array, dimension (LDA,N)
-*          On entry, the M-by-N matrix A.
-*          On exit,
-*          if JOBZ = 'O',  A is overwritten with the first N columns
-*                          of U (the left singular vectors, stored
-*                          columnwise) if M >= N;
-*                          A is overwritten with the first M rows
-*                          of V**T (the right singular vectors, stored
-*                          rowwise) otherwise.
-*          if JOBZ .ne. 'O', the contents of A are destroyed.
-*
-*  LDA     (input) INTEGER
-*          The leading dimension of the array A.  LDA >= max(1,M).
-*
-*  S       (output) REAL array, dimension (min(M,N))
-*          The singular values of A, sorted so that S(i) >= S(i+1).
-*
-*  U       (output) REAL array, dimension (LDU,UCOL)
-*          UCOL = M if JOBZ = 'A' or JOBZ = 'O' and M < N;
-*          UCOL = min(M,N) if JOBZ = 'S'.
-*          If JOBZ = 'A' or JOBZ = 'O' and M < N, U contains the M-by-M
-*          orthogonal matrix U;
-*          if JOBZ = 'S', U contains the first min(M,N) columns of U
-*          (the left singular vectors, stored columnwise);
-*          if JOBZ = 'O' and M >= N, or JOBZ = 'N', U is not referenced.
-*
-*  LDU     (input) INTEGER
-*          The leading dimension of the array U.  LDU >= 1; if
-*          JOBZ = 'S' or 'A' or JOBZ = 'O' and M < N, LDU >= M.
-*
-*  VT      (output) REAL array, dimension (LDVT,N)
-*          If JOBZ = 'A' or JOBZ = 'O' and M >= N, VT contains the
-*          N-by-N orthogonal matrix V**T;
-*          if JOBZ = 'S', VT contains the first min(M,N) rows of
-*          V**T (the right singular vectors, stored rowwise);
-*          if JOBZ = 'O' and M < N, or JOBZ = 'N', VT is not referenced.
-*
-*  LDVT    (input) INTEGER
-*          The leading dimension of the array VT.  LDVT >= 1; if
-*          JOBZ = 'A' or JOBZ = 'O' and M >= N, LDVT >= N;
-*          if JOBZ = 'S', LDVT >= min(M,N).
-*
-*  WORK    (workspace/output) REAL array, dimension (LWORK)
-*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK;
-*
-*  LWORK   (input) INTEGER
-*          The dimension of the array WORK. LWORK >= 1.
-*          If JOBZ = 'N',
-*            LWORK >= max(14*min(M,N)+4, 10*min(M,N)+2+
-*                     SMLSIZ*(SMLSIZ+8)) + max(M,N)
-*          where SMLSIZ is returned by ILAENV and is equal to the
-*          maximum size of the subproblems at the bottom of the
-*          computation tree (usually about 25).
-*          If JOBZ = 'O',
-*            LWORK >= 5*min(M,N)*min(M,N) + max(M,N) + 9*min(M,N).
-*          If JOBZ = 'S' or 'A'
-*            LWORK >= 4*min(M,N)*min(M,N) + max(M,N) + 9*min(M,N).
-*          For good performance, LWORK should generally be larger.
-*          If LWORK < 0 but other input arguments are legal, WORK(1)
-*          returns optimal LWORK.
-*
-*  IWORK   (workspace) INTEGER array, dimension (8*min(M,N))
-*
-*  INFO    (output) INTEGER
-*          = 0:  successful exit.
-*          < 0:  if INFO = -i, the i-th argument had an illegal value.
-*          > 0:  SBDSDC did not converge, updating process failed.
-*
-*  Further Details
-*  ===============
-*
-*  Based on contributions by
-*     Ming Gu and Huan Ren, Computer Science Division, University of
-*     California at Berkeley, USA
-*
 *  =====================================================================
 *
 *     .. Parameters ..
       REAL               ZERO, ONE
-      PARAMETER          ( ZERO = 0.0E+0, ONE = 1.0E+0 )
+      PARAMETER          ( ZERO = 0.0E0, ONE = 1.0E0 )
 *     ..
 *     .. Local Scalars ..
-      LOGICAL            WNTQA, WNTQAS, WNTQN, WNTQO, WNTQS
-      INTEGER            BDSPAC, BDSPAN, BLK, CHUNK, I, IE, IERR, IL,
+      LOGICAL            LQUERY, WNTQA, WNTQAS, WNTQN, WNTQO, WNTQS
+      INTEGER            BDSPAC, BLK, CHUNK, I, IE, IERR, IL,
      $                   IR, ISCL, ITAU, ITAUP, ITAUQ, IU, IVT, LDWKVT,
      $                   LDWRKL, LDWRKR, LDWRKU, MAXWRK, MINMN, MINWRK,
-     $                   MNTHR, NWORK, SMLSIZ, WRKBL
+     $                   MNTHR, NWORK, WRKBL
       REAL               ANRM, BIGNUM, EPS, SMLNUM
 *     ..
 *     .. Local Arrays ..
@@ -170,10 +258,10 @@
       LOGICAL            LSAME
       INTEGER            ILAENV
       REAL               SLAMCH, SLANGE
-      EXTERNAL           SLAMCH, SLANGE, ILAENV, LSAME
+      EXTERNAL           ILAENV, LSAME, SLAMCH, SLANGE
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          REAL, INT, MAX, MIN, SQRT
+      INTRINSIC          INT, MAX, MIN, SQRT
 *     ..
 *     .. Executable Statements ..
 *
@@ -181,13 +269,12 @@
 *
       INFO = 0
       MINMN = MIN( M, N )
-      MNTHR = INT( MINMN*11.0 / 6.0 )
       WNTQA = LSAME( JOBZ, 'A' )
       WNTQS = LSAME( JOBZ, 'S' )
       WNTQAS = WNTQA .OR. WNTQS
       WNTQO = LSAME( JOBZ, 'O' )
       WNTQN = LSAME( JOBZ, 'N' )
-      MINWRK = 1
+      LQUERY = ( LWORK.EQ.-1 )
 *
       IF( .NOT.( WNTQA .OR. WNTQS .OR. WNTQO .OR. WNTQN ) ) THEN
          INFO = -1
@@ -205,8 +292,6 @@
      $         ( WNTQO .AND. M.GE.N .AND. LDVT.LT.N ) ) THEN
          INFO = -10
       END IF
-*
-      SMLSIZ = ILAENV( 9, 'SGESDD', ' ', 0, 0, 0, 0 )
 *
 *     Compute workspace
 *      (Note: Comments in the code beginning "Workspace:" describe the
@@ -215,24 +300,30 @@
 *       NB refers to the optimal block size for the immediately
 *       following subroutine, as returned by ILAENV.)
 *
-      IF( INFO.EQ.0 .AND. LWORK.GE.1 .AND. M.GT.0 .AND. N.GT.0 ) THEN
-         IF( M.GE.N ) THEN
+      IF( INFO.EQ.0 ) THEN
+         MINWRK = 1
+         MAXWRK = 1
+         IF( M.GE.N .AND. MINMN.GT.0 ) THEN
 *
 *           Compute space needed for SBDSDC
 *
-            BDSPAC = 3*N*N + 7*N
-            BDSPAN = MAX( 12*N+4, 8*N+2+SMLSIZ*( SMLSIZ+8 ) )
+            MNTHR = INT( MINMN*11.0E0 / 6.0E0 )
+            IF( WNTQN ) THEN
+               BDSPAC = 7*N
+            ELSE
+               BDSPAC = 3*N*N + 4*N
+            END IF
             IF( M.GE.MNTHR ) THEN
                IF( WNTQN ) THEN
 *
 *                 Path 1 (M much larger than N, JOBZ='N')
 *
-                  MAXWRK = N + N*ILAENV( 1, 'SGEQRF', ' ', M, N, -1,
-     $                     -1 )
-                  MAXWRK = MAX( MAXWRK, 3*N+2*N*
-     $                     ILAENV( 1, 'SGEBRD', ' ', N, N, -1, -1 ) )
-                  MAXWRK = MAX( MAXWRK, BDSPAC )
-                  MINWRK = BDSPAC
+                  WRKBL = N + N*ILAENV( 1, 'SGEQRF', ' ', M, N, -1,
+     $                    -1 )
+                  WRKBL = MAX( WRKBL, 3*N+2*N*
+     $                    ILAENV( 1, 'SGEBRD', ' ', N, N, -1, -1 ) )
+                  MAXWRK = MAX( WRKBL, BDSPAC+N )
+                  MINWRK = BDSPAC + N
                ELSE IF( WNTQO ) THEN
 *
 *                 Path 2 (M much larger than N, JOBZ='O')
@@ -246,9 +337,9 @@
      $                    ILAENV( 1, 'SORMBR', 'QLN', N, N, N, -1 ) )
                   WRKBL = MAX( WRKBL, 3*N+N*
      $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*N )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*N )
                   MAXWRK = WRKBL + 2*N*N
-                  MINWRK = BDSPAC + 2*N*N + 2*N
+                  MINWRK = BDSPAC + 2*N*N + 3*N
                ELSE IF( WNTQS ) THEN
 *
 *                 Path 3 (M much larger than N, JOBZ='S')
@@ -262,9 +353,9 @@
      $                    ILAENV( 1, 'SORMBR', 'QLN', N, N, N, -1 ) )
                   WRKBL = MAX( WRKBL, 3*N+N*
      $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*N )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*N )
                   MAXWRK = WRKBL + N*N
-                  MINWRK = BDSPAC + N*N + 2*N
+                  MINWRK = BDSPAC + N*N + 3*N
                ELSE IF( WNTQA ) THEN
 *
 *                 Path 4 (M much larger than N, JOBZ='A')
@@ -278,9 +369,9 @@
      $                    ILAENV( 1, 'SORMBR', 'QLN', N, N, N, -1 ) )
                   WRKBL = MAX( WRKBL, 3*N+N*
      $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*N )
-                  MAXWRK = N*N + WRKBL
-                  MINWRK = BDSPAC + N*N + M + N
+                  WRKBL = MAX( WRKBL, BDSPAC+3*N )
+                  MAXWRK = WRKBL + N*N
+                  MINWRK = BDSPAC + N*N + 2*N + M
                END IF
             ELSE
 *
@@ -288,47 +379,54 @@
 *
                WRKBL = 3*N + ( M+N )*ILAENV( 1, 'SGEBRD', ' ', M, N, -1,
      $                 -1 )
-               IF( WNTQO ) THEN
+               IF( WNTQN ) THEN
+                  MAXWRK = MAX( WRKBL, BDSPAC+3*N )
+                  MINWRK = 3*N + MAX( M, BDSPAC )
+               ELSE IF( WNTQO ) THEN
                   WRKBL = MAX( WRKBL, 3*N+N*
      $                    ILAENV( 1, 'SORMBR', 'QLN', M, N, N, -1 ) )
                   WRKBL = MAX( WRKBL, 3*N+N*
      $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*N+M )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*N )
                   MAXWRK = WRKBL + M*N
-                  MINWRK = BDSPAC + N*N + 2*N + M
+                  MINWRK = 3*N + MAX( M, N*N+BDSPAC )
                ELSE IF( WNTQS ) THEN
-                  MAXWRK = MAX( MAXWRK, 3*N+N*
-     $                     ILAENV( 1, 'SORMBR', 'QLN', M, N, N, -1 ) )
-                  MAXWRK = MAX( MAXWRK, 3*N+N*
-     $                     ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
-                  MAXWRK = MAX( MAXWRK, BDSPAC+2*N+M )
-                  MINWRK = BDSPAC + 2*N + M
+                  WRKBL = MAX( WRKBL, 3*N+N*
+     $                    ILAENV( 1, 'SORMBR', 'QLN', M, N, N, -1 ) )
+                  WRKBL = MAX( WRKBL, 3*N+N*
+     $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
+                  MAXWRK = MAX( WRKBL, BDSPAC+3*N )
+                  MINWRK = 3*N + MAX( M, BDSPAC )
                ELSE IF( WNTQA ) THEN
-                  MAXWRK = MAX( MAXWRK, 3*N+M*
-     $                     ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
-                  MAXWRK = MAX( MAXWRK, 3*N+N*
-     $                     ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
-                  MAXWRK = MAX( MAXWRK, BDSPAC+2*N+M )
-                  MINWRK = BDSPAC + 2*N + M
+                  WRKBL = MAX( WRKBL, 3*N+M*
+     $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
+                  WRKBL = MAX( WRKBL, 3*N+N*
+     $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, N, -1 ) )
+                  MAXWRK = MAX( MAXWRK, BDSPAC+3*N )
+                  MINWRK = 3*N + MAX( M, BDSPAC )
                END IF
             END IF
-         ELSE
+         ELSE IF ( MINMN.GT.0 ) THEN
 *
 *           Compute space needed for SBDSDC
 *
-            BDSPAC = 3*M*M + 7*M
-            BDSPAN = MAX( 12*M+4, 8*M+2+SMLSIZ*( SMLSIZ+8 ) )
+            MNTHR = INT( MINMN*11.0E0 / 6.0E0 )
+            IF( WNTQN ) THEN
+               BDSPAC = 7*M
+            ELSE
+               BDSPAC = 3*M*M + 4*M
+            END IF
             IF( N.GE.MNTHR ) THEN
                IF( WNTQN ) THEN
 *
 *                 Path 1t (N much larger than M, JOBZ='N')
 *
-                  MAXWRK = M + M*ILAENV( 1, 'SGELQF', ' ', M, N, -1,
-     $                     -1 )
-                  MAXWRK = MAX( MAXWRK, 3*M+2*M*
-     $                     ILAENV( 1, 'SGEBRD', ' ', M, M, -1, -1 ) )
-                  MAXWRK = MAX( MAXWRK, BDSPAC )
-                  MINWRK = BDSPAC
+                  WRKBL = M + M*ILAENV( 1, 'SGELQF', ' ', M, N, -1,
+     $                    -1 )
+                  WRKBL = MAX( WRKBL, 3*M+2*M*
+     $                    ILAENV( 1, 'SGEBRD', ' ', M, M, -1, -1 ) )
+                  MAXWRK = MAX( WRKBL, BDSPAC+M )
+                  MINWRK = BDSPAC + M
                ELSE IF( WNTQO ) THEN
 *
 *                 Path 2t (N much larger than M, JOBZ='O')
@@ -342,9 +440,9 @@
      $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, M, -1 ) )
                   WRKBL = MAX( WRKBL, 3*M+M*
      $                    ILAENV( 1, 'SORMBR', 'PRT', M, M, M, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*M )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*M )
                   MAXWRK = WRKBL + 2*M*M
-                  MINWRK = BDSPAC + 2*M*M + 2*M
+                  MINWRK = BDSPAC + 2*M*M + 3*M
                ELSE IF( WNTQS ) THEN
 *
 *                 Path 3t (N much larger than M, JOBZ='S')
@@ -358,9 +456,9 @@
      $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, M, -1 ) )
                   WRKBL = MAX( WRKBL, 3*M+M*
      $                    ILAENV( 1, 'SORMBR', 'PRT', M, M, M, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*M )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*M )
                   MAXWRK = WRKBL + M*M
-                  MINWRK = BDSPAC + M*M + 2*M
+                  MINWRK = BDSPAC + M*M + 3*M
                ELSE IF( WNTQA ) THEN
 *
 *                 Path 4t (N much larger than M, JOBZ='A')
@@ -374,9 +472,9 @@
      $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, M, -1 ) )
                   WRKBL = MAX( WRKBL, 3*M+M*
      $                    ILAENV( 1, 'SORMBR', 'PRT', M, M, M, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*M )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*M )
                   MAXWRK = WRKBL + M*M
-                  MINWRK = BDSPAC + M*M + M + N
+                  MINWRK = BDSPAC + M*M + 3*M
                END IF
             ELSE
 *
@@ -384,47 +482,52 @@
 *
                WRKBL = 3*M + ( M+N )*ILAENV( 1, 'SGEBRD', ' ', M, N, -1,
      $                 -1 )
-               IF( WNTQO ) THEN
+               IF( WNTQN ) THEN
+                  MAXWRK = MAX( WRKBL, BDSPAC+3*M )
+                  MINWRK = 3*M + MAX( N, BDSPAC )
+               ELSE IF( WNTQO ) THEN
                   WRKBL = MAX( WRKBL, 3*M+M*
      $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
                   WRKBL = MAX( WRKBL, 3*M+M*
      $                    ILAENV( 1, 'SORMBR', 'PRT', M, N, M, -1 ) )
-                  WRKBL = MAX( WRKBL, BDSPAC+2*M )
+                  WRKBL = MAX( WRKBL, BDSPAC+3*M )
                   MAXWRK = WRKBL + M*N
-                  MINWRK = BDSPAC + M*M + 2*M + N
+                  MINWRK = 3*M + MAX( N, M*M+BDSPAC )
                ELSE IF( WNTQS ) THEN
-                  MAXWRK = MAX( MAXWRK, 3*M+M*
-     $                     ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
-                  MAXWRK = MAX( MAXWRK, 3*M+M*
-     $                     ILAENV( 1, 'SORMBR', 'PRT', M, N, M, -1 ) )
-                  MAXWRK = MAX( MAXWRK, BDSPAC+2*M )
-                  MINWRK = BDSPAC + 2*M + N
+                  WRKBL = MAX( WRKBL, 3*M+M*
+     $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
+                  WRKBL = MAX( WRKBL, 3*M+M*
+     $                    ILAENV( 1, 'SORMBR', 'PRT', M, N, M, -1 ) )
+                  MAXWRK = MAX( WRKBL, BDSPAC+3*M )
+                  MINWRK = 3*M + MAX( N, BDSPAC )
                ELSE IF( WNTQA ) THEN
-                  MAXWRK = MAX( MAXWRK, 3*M+M*
-     $                     ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
-                  MAXWRK = MAX( MAXWRK, 3*M+N*
-     $                     ILAENV( 1, 'SORMBR', 'PRT', N, N, M, -1 ) )
-                  MAXWRK = MAX( MAXWRK, BDSPAC+2*M )
-                  MINWRK = BDSPAC + 2*M + N
+                  WRKBL = MAX( WRKBL, 3*M+M*
+     $                    ILAENV( 1, 'SORMBR', 'QLN', M, M, N, -1 ) )
+                  WRKBL = MAX( WRKBL, 3*M+M*
+     $                    ILAENV( 1, 'SORMBR', 'PRT', N, N, M, -1 ) )
+                  MAXWRK = MAX( WRKBL, BDSPAC+3*M )
+                  MINWRK = 3*M + MAX( N, BDSPAC )
                END IF
             END IF
          END IF
+         MAXWRK = MAX( MAXWRK, MINWRK )
          WORK( 1 ) = MAXWRK
+*
+         IF( LWORK.LT.MINWRK .AND. .NOT.LQUERY ) THEN
+            INFO = -12
+         END IF
       END IF
 *
-      IF( LWORK.LT.MINWRK ) THEN
-         INFO = -12
-      END IF
       IF( INFO.NE.0 ) THEN
          CALL XERBLA( 'SGESDD', -INFO )
          RETURN
+      ELSE IF( LQUERY ) THEN
+         RETURN
       END IF
 *
 *     Quick return if possible
 *
       IF( M.EQ.0 .OR. N.EQ.0 ) THEN
-         IF( LWORK.GE.1 )
-     $      WORK( 1 ) = ONE
          RETURN
       END IF
 *
@@ -485,7 +588,7 @@
                NWORK = IE + N
 *
 *              Perform bidiagonal SVD, computing singular values only
-*              (Workspace: need BDSPAN)
+*              (Workspace: need N+BDSPAC)
 *
                CALL SBDSDC( 'U', 'N', N, S, WORK( IE ), DUM, 1, DUM, 1,
      $                      DUM, IDUM, WORK( NWORK ), IWORK, INFO )
@@ -500,10 +603,10 @@
 *
 *              WORK(IR) is LDWRKR by N
 *
-               IF( LWORK.GE.LDA*N+4*N*N+9*N ) THEN
+               IF( LWORK.GE.LDA*N+N*N+3*N+BDSPAC ) THEN
                   LDWRKR = LDA
                ELSE
-                  LDWRKR = ( LWORK-4*N*N-9*N ) / N
+                  LDWRKR = ( LWORK-N*N-3*N-BDSPAC ) / N
                END IF
                ITAU = IR + LDWRKR*N
                NWORK = ITAU + N
@@ -545,7 +648,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in WORK(IU) and computing right
 *              singular vectors of bidiagonal matrix in VT
-*              (Workspace: need 2*N*N+BDSPAC)
+*              (Workspace: need N+N*N+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', N, S, WORK( IE ), WORK( IU ), N,
      $                      VT, LDVT, DUM, IDUM, WORK( NWORK ), IWORK,
@@ -621,7 +724,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagoal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in VT
-*              (Workspace: need N*N+BDSPAC)
+*              (Workspace: need N+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', N, S, WORK( IE ), U, LDU, VT,
      $                      LDVT, DUM, IDUM, WORK( NWORK ), IWORK,
@@ -662,7 +765,7 @@
                NWORK = ITAU + N
 *
 *              Compute A=Q*R, copying result to U
-*              (Workspace: need N*N+2*N, prefer N*N+N+N*NB)
+*              (Workspace: need N*N+N+M, prefer N*N+N+M*NB)
 *
                CALL SGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
@@ -691,7 +794,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in WORK(IU) and computing right
 *              singular vectors of bidiagonal matrix in VT
-*              (Workspace: need N*N+BDSPAC)
+*              (Workspace: need N+N*N+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', N, S, WORK( IE ), WORK( IU ), N,
      $                      VT, LDVT, DUM, IDUM, WORK( NWORK ), IWORK,
@@ -742,13 +845,13 @@
             IF( WNTQN ) THEN
 *
 *              Perform bidiagonal SVD, only computing singular values
-*              (Workspace: need BDSPAN)
+*              (Workspace: need N+BDSPAC)
 *
                CALL SBDSDC( 'U', 'N', N, S, WORK( IE ), DUM, 1, DUM, 1,
      $                      DUM, IDUM, WORK( NWORK ), IWORK, INFO )
             ELSE IF( WNTQO ) THEN
                IU = NWORK
-               IF( LWORK.GE.M*N+3*N*N+9*N ) THEN
+               IF( LWORK.GE.M*N+3*N+BDSPAC ) THEN
 *
 *                 WORK( IU ) is M by N
 *
@@ -773,7 +876,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in WORK(IU) and computing right
 *              singular vectors of bidiagonal matrix in VT
-*              (Workspace: need N*N+BDSPAC)
+*              (Workspace: need N+N*N+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', N, S, WORK( IE ), WORK( IU ),
      $                      LDWRKU, VT, LDVT, DUM, IDUM, WORK( NWORK ),
@@ -786,7 +889,7 @@
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
-               IF( LWORK.GE.M*N+3*N*N+9*N ) THEN
+               IF( LWORK.GE.M*N+3*N+BDSPAC ) THEN
 *
 *                 Overwrite WORK(IU) by left singular vectors of A
 *                 (Workspace: need N*N+2*N, prefer N*N+N+N*NB)
@@ -826,7 +929,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in VT
-*              (Workspace: need BDSPAC)
+*              (Workspace: need N+BDSPAC)
 *
                CALL SLASET( 'F', M, N, ZERO, ZERO, U, LDU )
                CALL SBDSDC( 'U', 'I', N, S, WORK( IE ), U, LDU, VT,
@@ -843,12 +946,12 @@
                CALL SORMBR( 'P', 'R', 'T', N, N, N, A, LDA,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
-            ELSE
+            ELSE IF( WNTQA ) THEN
 *
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in VT
-*              (Workspace: need BDSPAC)
+*              (Workspace: need N+BDSPAC)
 *
                CALL SLASET( 'F', M, M, ZERO, ZERO, U, LDU )
                CALL SBDSDC( 'U', 'I', N, S, WORK( IE ), U, LDU, VT,
@@ -857,8 +960,10 @@
 *
 *              Set the right corner of U to identity matrix
 *
-               CALL SLASET( 'F', M-N, M-N, ZERO, ONE, U( N+1, N+1 ),
-     $                      LDU )
+               IF( M.GT.N ) THEN
+                  CALL SLASET( 'F', M-N, M-N, ZERO, ONE, U( N+1, N+1 ),
+     $                         LDU )
+               END IF
 *
 *              Overwrite U by left singular vectors of A and VT
 *              by right singular vectors of A
@@ -913,7 +1018,7 @@
                NWORK = IE + M
 *
 *              Perform bidiagonal SVD, computing singular values only
-*              (Workspace: need BDSPAN)
+*              (Workspace: need M+BDSPAC)
 *
                CALL SBDSDC( 'U', 'N', M, S, WORK( IE ), DUM, 1, DUM, 1,
      $                      DUM, IDUM, WORK( NWORK ), IWORK, INFO )
@@ -929,7 +1034,7 @@
 *              IVT is M by M
 *
                IL = IVT + M*M
-               IF( LWORK.GE.M*N+4*M*M+9*M ) THEN
+               IF( LWORK.GE.M*N+M*M+3*M+BDSPAC ) THEN
 *
 *                 WORK(IL) is M by N
 *
@@ -974,7 +1079,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U, and computing right singular
 *              vectors of bidiagonal matrix in WORK(IVT)
-*              (Workspace: need 2*M*M+BDSPAC)
+*              (Workspace: need M+M*M+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', M, S, WORK( IE ), U, LDU,
      $                      WORK( IVT ), M, DUM, IDUM, WORK( NWORK ),
@@ -1049,7 +1154,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in VT
-*              (Workspace: need M*M+BDSPAC)
+*              (Workspace: need M+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', M, S, WORK( IE ), U, LDU, VT,
      $                      LDVT, DUM, IDUM, WORK( NWORK ), IWORK,
@@ -1096,7 +1201,7 @@
                CALL SLACPY( 'U', M, N, A, LDA, VT, LDVT )
 *
 *              Generate Q in VT
-*              (Workspace: need M*M+M+N, prefer M*M+M+N*NB)
+*              (Workspace: need M*M+2*M, prefer M*M+M+M*NB)
 *
                CALL SORGLQ( N, N, M, VT, LDVT, WORK( ITAU ),
      $                      WORK( NWORK ), LWORK-NWORK+1, IERR )
@@ -1119,7 +1224,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in WORK(IVT)
-*              (Workspace: need M*M+BDSPAC)
+*              (Workspace: need M+M*M+BDSPAC)
 *
                CALL SBDSDC( 'U', 'I', M, S, WORK( IE ), U, LDU,
      $                      WORK( IVT ), LDWKVT, DUM, IDUM,
@@ -1170,14 +1275,14 @@
             IF( WNTQN ) THEN
 *
 *              Perform bidiagonal SVD, only computing singular values
-*              (Workspace: need BDSPAN)
+*              (Workspace: need M+BDSPAC)
 *
                CALL SBDSDC( 'L', 'N', M, S, WORK( IE ), DUM, 1, DUM, 1,
      $                      DUM, IDUM, WORK( NWORK ), IWORK, INFO )
             ELSE IF( WNTQO ) THEN
                LDWKVT = M
                IVT = NWORK
-               IF( LWORK.GE.M*N+3*M*M+9*M ) THEN
+               IF( LWORK.GE.M*N+3*M+BDSPAC ) THEN
 *
 *                 WORK( IVT ) is M by N
 *
@@ -1212,7 +1317,7 @@
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
-               IF( LWORK.GE.M*N+3*M*M+9*M ) THEN
+               IF( LWORK.GE.M*N+3*M+BDSPAC ) THEN
 *
 *                 Overwrite WORK(IVT) by left singular vectors of A
 *                 (Workspace: need M*M+2*M, prefer M*M+M+M*NB)
@@ -1251,7 +1356,7 @@
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in VT
-*              (Workspace: need BDSPAC)
+*              (Workspace: need M+BDSPAC)
 *
                CALL SLASET( 'F', M, N, ZERO, ZERO, VT, LDVT )
                CALL SBDSDC( 'L', 'I', M, S, WORK( IE ), U, LDU, VT,
@@ -1268,12 +1373,12 @@
                CALL SORMBR( 'P', 'R', 'T', M, N, M, A, LDA,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
-            ELSE
+            ELSE IF( WNTQA ) THEN
 *
 *              Perform bidiagonal SVD, computing left singular vectors
 *              of bidiagonal matrix in U and computing right singular
 *              vectors of bidiagonal matrix in VT
-*              (Workspace: need BDSPAC)
+*              (Workspace: need M+BDSPAC)
 *
                CALL SLASET( 'F', N, N, ZERO, ZERO, VT, LDVT )
                CALL SBDSDC( 'L', 'I', M, S, WORK( IE ), U, LDU, VT,
@@ -1282,8 +1387,10 @@
 *
 *              Set the right corner of VT to identity matrix
 *
-               CALL SLASET( 'F', N-M, N-M, ZERO, ONE, VT( M+1, M+1 ),
-     $                      LDVT )
+               IF( N.GT.M ) THEN
+                  CALL SLASET( 'F', N-M, N-M, ZERO, ONE, VT( M+1, M+1 ),
+     $                         LDVT )
+               END IF
 *
 *              Overwrite U by left singular vectors of A and VT
 *              by right singular vectors of A
@@ -1307,20 +1414,14 @@
          IF( ANRM.GT.BIGNUM )
      $      CALL SLASCL( 'G', 0, 0, BIGNUM, ANRM, MINMN, 1, S, MINMN,
      $                   IERR )
-         IF( INFO.NE.0 .AND. ANRM.GT.BIGNUM )
-     $      CALL SLASCL( 'G', 0, 0, BIGNUM, ANRM, MINMN-1, 1, WORK( 2 ),
-     $                   MINMN, IERR )
          IF( ANRM.LT.SMLNUM )
      $      CALL SLASCL( 'G', 0, 0, SMLNUM, ANRM, MINMN, 1, S, MINMN,
      $                   IERR )
-         IF( INFO.NE.0 .AND. ANRM.LT.SMLNUM )
-     $      CALL SLASCL( 'G', 0, 0, SMLNUM, ANRM, MINMN-1, 1, WORK( 2 ),
-     $                   MINMN, IERR )
       END IF
 *
 *     Return optimal workspace in WORK(1)
 *
-      WORK( 1 ) = REAL( MAXWRK )
+      WORK( 1 ) = MAXWRK
 *
       RETURN
 *
