@@ -1,9 +1,168 @@
+*> \brief \b ZHPTRF
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*> \htmlonly
+*> Download ZHPTRF + dependencies 
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhptrf.f"> 
+*> [TGZ]</a> 
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhptrf.f"> 
+*> [ZIP]</a> 
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhptrf.f"> 
+*> [TXT]</a>
+*> \endhtmlonly 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ZHPTRF( UPLO, N, AP, IPIV, INFO )
+* 
+*       .. Scalar Arguments ..
+*       CHARACTER          UPLO
+*       INTEGER            INFO, N
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            IPIV( * )
+*       COMPLEX*16         AP( * )
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ZHPTRF computes the factorization of a complex Hermitian packed
+*> matrix A using the Bunch-Kaufman diagonal pivoting method:
+*>
+*>    A = U*D*U**H  or  A = L*D*L**H
+*>
+*> where U (or L) is a product of permutation and unit upper (lower)
+*> triangular matrices, and D is Hermitian and block diagonal with
+*> 1-by-1 and 2-by-2 diagonal blocks.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] UPLO
+*> \verbatim
+*>          UPLO is CHARACTER*1
+*>          = 'U':  Upper triangle of A is stored;
+*>          = 'L':  Lower triangle of A is stored.
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>          The order of the matrix A.  N >= 0.
+*> \endverbatim
+*>
+*> \param[in,out] AP
+*> \verbatim
+*>          AP is COMPLEX*16 array, dimension (N*(N+1)/2)
+*>          On entry, the upper or lower triangle of the Hermitian matrix
+*>          A, packed columnwise in a linear array.  The j-th column of A
+*>          is stored in the array AP as follows:
+*>          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;
+*>          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.
+*>
+*>          On exit, the block diagonal matrix D and the multipliers used
+*>          to obtain the factor U or L, stored as a packed triangular
+*>          matrix overwriting A (see below for further details).
+*> \endverbatim
+*>
+*> \param[out] IPIV
+*> \verbatim
+*>          IPIV is INTEGER array, dimension (N)
+*>          Details of the interchanges and the block structure of D.
+*>          If IPIV(k) > 0, then rows and columns k and IPIV(k) were
+*>          interchanged and D(k,k) is a 1-by-1 diagonal block.
+*>          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and
+*>          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)
+*>          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =
+*>          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were
+*>          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          = 0: successful exit
+*>          < 0: if INFO = -i, the i-th argument had an illegal value
+*>          > 0: if INFO = i, D(i,i) is exactly zero.  The factorization
+*>               has been completed, but the block diagonal matrix D is
+*>               exactly singular, and division by zero will occur if it
+*>               is used to solve a system of equations.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2011
+*
+*> \ingroup complex16OTHERcomputational
+*
+*> \par Further Details:
+*  =====================
+*>
+*> \verbatim
+*>
+*>  If UPLO = 'U', then A = U*D*U**H, where
+*>     U = P(n)*U(n)* ... *P(k)U(k)* ...,
+*>  i.e., U is a product of terms P(k)*U(k), where k decreases from n to
+*>  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
+*>  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
+*>  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such
+*>  that if the diagonal block D(k) is of order s (s = 1 or 2), then
+*>
+*>             (   I    v    0   )   k-s
+*>     U(k) =  (   0    I    0   )   s
+*>             (   0    0    I   )   n-k
+*>                k-s   s   n-k
+*>
+*>  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).
+*>  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),
+*>  and A(k,k), and v overwrites A(1:k-2,k-1:k).
+*>
+*>  If UPLO = 'L', then A = L*D*L**H, where
+*>     L = P(1)*L(1)* ... *P(k)*L(k)* ...,
+*>  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to
+*>  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
+*>  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
+*>  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such
+*>  that if the diagonal block D(k) is of order s (s = 1 or 2), then
+*>
+*>             (   I    0     0   )  k-1
+*>     L(k) =  (   0    I     0   )  s
+*>             (   0    v     I   )  n-k-s+1
+*>                k-1   s  n-k-s+1
+*>
+*>  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).
+*>  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),
+*>  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).
+*> \endverbatim
+*
+*> \par Contributors:
+*  ==================
+*>
+*>  J. Lewis, Boeing Computer Services Company
+*
+*  =====================================================================
       SUBROUTINE ZHPTRF( UPLO, N, AP, IPIV, INFO )
 *
-*  -- LAPACK routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK computational routine (version 3.4.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2011
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -14,94 +173,6 @@
       COMPLEX*16         AP( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ZHPTRF computes the factorization of a complex Hermitian packed
-*  matrix A using the Bunch-Kaufman diagonal pivoting method:
-*
-*     A = U*D*U**H  or  A = L*D*L**H
-*
-*  where U (or L) is a product of permutation and unit upper (lower)
-*  triangular matrices, and D is Hermitian and block diagonal with
-*  1-by-1 and 2-by-2 diagonal blocks.
-*
-*  Arguments
-*  =========
-*
-*  UPLO    (input) CHARACTER*1
-*          = 'U':  Upper triangle of A is stored;
-*          = 'L':  Lower triangle of A is stored.
-*
-*  N       (input) INTEGER
-*          The order of the matrix A.  N >= 0.
-*
-*  AP      (input/output) COMPLEX*16 array, dimension (N*(N+1)/2)
-*          On entry, the upper or lower triangle of the Hermitian matrix
-*          A, packed columnwise in a linear array.  The j-th column of A
-*          is stored in the array AP as follows:
-*          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;
-*          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.
-*
-*          On exit, the block diagonal matrix D and the multipliers used
-*          to obtain the factor U or L, stored as a packed triangular
-*          matrix overwriting A (see below for further details).
-*
-*  IPIV    (output) INTEGER array, dimension (N)
-*          Details of the interchanges and the block structure of D.
-*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were
-*          interchanged and D(k,k) is a 1-by-1 diagonal block.
-*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and
-*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)
-*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =
-*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were
-*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.
-*
-*  INFO    (output) INTEGER
-*          = 0: successful exit
-*          < 0: if INFO = -i, the i-th argument had an illegal value
-*          > 0: if INFO = i, D(i,i) is exactly zero.  The factorization
-*               has been completed, but the block diagonal matrix D is
-*               exactly singular, and division by zero will occur if it
-*               is used to solve a system of equations.
-*
-*  Further Details
-*  ===============
-*
-*  If UPLO = 'U', then A = U*D*U', where
-*     U = P(n)*U(n)* ... *P(k)U(k)* ...,
-*  i.e., U is a product of terms P(k)*U(k), where k decreases from n to
-*  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
-*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
-*  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such
-*  that if the diagonal block D(k) is of order s (s = 1 or 2), then
-*
-*             (   I    v    0   )   k-s
-*     U(k) =  (   0    I    0   )   s
-*             (   0    0    I   )   n-k
-*                k-s   s   n-k
-*
-*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).
-*  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),
-*  and A(k,k), and v overwrites A(1:k-2,k-1:k).
-*
-*  If UPLO = 'L', then A = L*D*L', where
-*     L = P(1)*L(1)* ... *P(k)*L(k)* ...,
-*  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to
-*  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
-*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
-*  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such
-*  that if the diagonal block D(k) is of order s (s = 1 or 2), then
-*
-*             (   I    0     0   )  k-1
-*     L(k) =  (   0    I     0   )  s
-*             (   0    v     I   )  n-k-s+1
-*                k-1   s  n-k-s+1
-*
-*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).
-*  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),
-*  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -112,21 +183,23 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            UPPER
-      INTEGER            IMAX, J, JMAX, K, KC, KK, KNC, KP, KPC, KSTEP,
-     $                   KX, NPP
-      DOUBLE PRECISION   ABSAKK, ALPHA, C, COLMAX, R1, R2, ROWMAX
-      COMPLEX*16         S, T, ZDUM
+      INTEGER            I, IMAX, J, JMAX, K, KC, KK, KNC, KP, KPC,
+     $                   KSTEP, KX, NPP
+      DOUBLE PRECISION   ABSAKK, ALPHA, COLMAX, D, D11, D22, R1, ROWMAX,
+     $                   TT
+      COMPLEX*16         D12, D21, T, WK, WKM1, WKP1, ZDUM
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
       INTEGER            IZAMAX
-      EXTERNAL           LSAME, IZAMAX
+      DOUBLE PRECISION   DLAPY2
+      EXTERNAL           LSAME, IZAMAX, DLAPY2
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           XERBLA, ZDSCAL, ZHPR, ZLAEV2, ZROT, ZSWAP
+      EXTERNAL           XERBLA, ZDSCAL, ZHPR, ZSWAP
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ABS, DBLE, DCONJG, DIMAG, MAX, SQRT
+      INTRINSIC          ABS, DBLE, DCMPLX, DCONJG, DIMAG, MAX, SQRT
 *     ..
 *     .. Statement Functions ..
       DOUBLE PRECISION   CABS1
@@ -156,7 +229,7 @@
 *
       IF( UPPER ) THEN
 *
-*        Factorize A as U*D*U' using the upper triangle of A
+*        Factorize A as U*D*U**H using the upper triangle of A
 *
 *        K is the main loop index, decreasing from N to 1 in steps of
 *        1 or 2
@@ -169,7 +242,7 @@
 *        If K < 1, exit from loop
 *
          IF( K.LT.1 )
-     $      GO TO 70
+     $      GO TO 110
          KSTEP = 1
 *
 *        Determine rows and columns to be interchanged and whether
@@ -288,7 +361,7 @@
 *
 *              Perform a rank-1 update of A(1:k-1,1:k-1) as
 *
-*              A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)'
+*              A := A - U(k)*D(k)*U(k)**H = A - W(k)*1/D(k)*W(k)**H
 *
                R1 = ONE / DBLE( AP( KC+K-1 ) )
                CALL ZHPR( UPLO, K-1, -R1, AP( KC ), 1, AP )
@@ -307,25 +380,37 @@
 *
 *              Perform a rank-2 update of A(1:k-2,1:k-2) as
 *
-*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )'
-*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )'
+*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )**H
+*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )**H
 *
-*              Convert this to two rank-1 updates by using the eigen-
-*              decomposition of D(k)
+               IF( K.GT.2 ) THEN
 *
-               CALL ZLAEV2( AP( KC-1 ), AP( KC+K-2 ), AP( KC+K-1 ), R1,
-     $                      R2, C, S )
-               R1 = ONE / R1
-               R2 = ONE / R2
-               CALL ZROT( K-2, AP( KNC ), 1, AP( KC ), 1, C, S )
-               CALL ZHPR( UPLO, K-2, -R1, AP( KNC ), 1, AP )
-               CALL ZHPR( UPLO, K-2, -R2, AP( KC ), 1, AP )
+                  D = DLAPY2( DBLE( AP( K-1+( K-1 )*K / 2 ) ),
+     $                DIMAG( AP( K-1+( K-1 )*K / 2 ) ) )
+                  D22 = DBLE( AP( K-1+( K-2 )*( K-1 ) / 2 ) ) / D
+                  D11 = DBLE( AP( K+( K-1 )*K / 2 ) ) / D
+                  TT = ONE / ( D11*D22-ONE )
+                  D12 = AP( K-1+( K-1 )*K / 2 ) / D
+                  D = TT / D
 *
-*              Store U(k) and U(k-1) in columns k and k-1
+                  DO 50 J = K - 2, 1, -1
+                     WKM1 = D*( D11*AP( J+( K-2 )*( K-1 ) / 2 )-
+     $                      DCONJG( D12 )*AP( J+( K-1 )*K / 2 ) )
+                     WK = D*( D22*AP( J+( K-1 )*K / 2 )-D12*
+     $                    AP( J+( K-2 )*( K-1 ) / 2 ) )
+                     DO 40 I = J, 1, -1
+                        AP( I+( J-1 )*J / 2 ) = AP( I+( J-1 )*J / 2 ) -
+     $                     AP( I+( K-1 )*K / 2 )*DCONJG( WK ) -
+     $                     AP( I+( K-2 )*( K-1 ) / 2 )*DCONJG( WKM1 )
+   40                CONTINUE
+                     AP( J+( K-1 )*K / 2 ) = WK
+                     AP( J+( K-2 )*( K-1 ) / 2 ) = WKM1
+                     AP( J+( J-1 )*J / 2 ) = DCMPLX( DBLE( AP( J+( J-
+     $                                       1 )*J / 2 ) ), 0.0D+0 )
+   50             CONTINUE
+*
+               END IF
 *
-               CALL ZDSCAL( K-2, R1, AP( KNC ), 1 )
-               CALL ZDSCAL( K-2, R2, AP( KC ), 1 )
-               CALL ZROT( K-2, AP( KNC ), 1, AP( KC ), 1, C, -S )
             END IF
          END IF
 *
@@ -346,7 +431,7 @@
 *
       ELSE
 *
-*        Factorize A as L*D*L' using the lower triangle of A
+*        Factorize A as L*D*L**H using the lower triangle of A
 *
 *        K is the main loop index, increasing from 1 to N in steps of
 *        1 or 2
@@ -354,13 +439,13 @@
          K = 1
          KC = 1
          NPP = N*( N+1 ) / 2
-   40    CONTINUE
+   60    CONTINUE
          KNC = KC
 *
 *        If K > N, exit from loop
 *
          IF( K.GT.N )
-     $      GO TO 70
+     $      GO TO 110
          KSTEP = 1
 *
 *        Determine rows and columns to be interchanged and whether
@@ -399,13 +484,13 @@
 *
                ROWMAX = ZERO
                KX = KC + IMAX - K
-               DO 50 J = K, IMAX - 1
+               DO 70 J = K, IMAX - 1
                   IF( CABS1( AP( KX ) ).GT.ROWMAX ) THEN
                      ROWMAX = CABS1( AP( KX ) )
                      JMAX = J
                   END IF
                   KX = KX + N - J
-   50          CONTINUE
+   70          CONTINUE
                KPC = NPP - ( N-IMAX+1 )*( N-IMAX+2 ) / 2 + 1
                IF( IMAX.LT.N ) THEN
                   JMAX = IMAX + IZAMAX( N-IMAX, AP( KPC+1 ), 1 )
@@ -445,12 +530,12 @@
      $            CALL ZSWAP( N-KP, AP( KNC+KP-KK+1 ), 1, AP( KPC+1 ),
      $                        1 )
                KX = KNC + KP - KK
-               DO 60 J = KK + 1, KP - 1
+               DO 80 J = KK + 1, KP - 1
                   KX = KX + N - J + 1
                   T = DCONJG( AP( KNC+J-KK ) )
                   AP( KNC+J-KK ) = DCONJG( AP( KX ) )
                   AP( KX ) = T
-   60          CONTINUE
+   80          CONTINUE
                AP( KNC+KP-KK ) = DCONJG( AP( KNC+KP-KK ) )
                R1 = DBLE( AP( KNC ) )
                AP( KNC ) = DBLE( AP( KPC ) )
@@ -481,7 +566,7 @@
 *
 *                 Perform a rank-1 update of A(k+1:n,k+1:n) as
 *
-*                 A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)'
+*                 A := A - L(k)*D(k)*L(k)**H = A - W(k)*(1/D(k))*W(k)**H
 *
                   R1 = ONE / DBLE( AP( KC ) )
                   CALL ZHPR( UPLO, N-K, -R1, AP( KC+1 ), 1,
@@ -504,29 +589,38 @@
 *
 *                 Perform a rank-2 update of A(k+2:n,k+2:n) as
 *
-*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )'
-*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )'
+*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )**H
+*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )**H
 *
-*                 Convert this to two rank-1 updates by using the eigen-
-*                 decomposition of D(k)
+*                 where L(k) and L(k+1) are the k-th and (k+1)-th
+*                 columns of L
 *
-                  CALL ZLAEV2( AP( KC ), DCONJG( AP( KC+1 ) ),
-     $                         AP( KNC ), R1, R2, C, S )
-                  R1 = ONE / R1
-                  R2 = ONE / R2
-                  CALL ZROT( N-K-1, AP( KC+2 ), 1, AP( KNC+1 ), 1, C,
-     $                       S )
-                  CALL ZHPR( UPLO, N-K-1, -R1, AP( KC+2 ), 1,
-     $                       AP( KNC+N-K ) )
-                  CALL ZHPR( UPLO, N-K-1, -R2, AP( KNC+1 ), 1,
-     $                       AP( KNC+N-K ) )
+                  D = DLAPY2( DBLE( AP( K+1+( K-1 )*( 2*N-K ) / 2 ) ),
+     $                DIMAG( AP( K+1+( K-1 )*( 2*N-K ) / 2 ) ) )
+                  D11 = DBLE( AP( K+1+K*( 2*N-K-1 ) / 2 ) ) / D
+                  D22 = DBLE( AP( K+( K-1 )*( 2*N-K ) / 2 ) ) / D
+                  TT = ONE / ( D11*D22-ONE )
+                  D21 = AP( K+1+( K-1 )*( 2*N-K ) / 2 ) / D
+                  D = TT / D
 *
-*                 Store L(k) and L(k+1) in columns k and k+1
-*
-                  CALL ZDSCAL( N-K-1, R1, AP( KC+2 ), 1 )
-                  CALL ZDSCAL( N-K-1, R2, AP( KNC+1 ), 1 )
-                  CALL ZROT( N-K-1, AP( KC+2 ), 1, AP( KNC+1 ), 1, C,
-     $                       -S )
+                  DO 100 J = K + 2, N
+                     WK = D*( D11*AP( J+( K-1 )*( 2*N-K ) / 2 )-D21*
+     $                    AP( J+K*( 2*N-K-1 ) / 2 ) )
+                     WKP1 = D*( D22*AP( J+K*( 2*N-K-1 ) / 2 )-
+     $                      DCONJG( D21 )*AP( J+( K-1 )*( 2*N-K ) /
+     $                      2 ) )
+                     DO 90 I = J, N
+                        AP( I+( J-1 )*( 2*N-J ) / 2 ) = AP( I+( J-1 )*
+     $                     ( 2*N-J ) / 2 ) - AP( I+( K-1 )*( 2*N-K ) /
+     $                     2 )*DCONJG( WK ) - AP( I+K*( 2*N-K-1 ) / 2 )*
+     $                     DCONJG( WKP1 )
+   90                CONTINUE
+                     AP( J+( K-1 )*( 2*N-K ) / 2 ) = WK
+                     AP( J+K*( 2*N-K-1 ) / 2 ) = WKP1
+                     AP( J+( J-1 )*( 2*N-J ) / 2 )
+     $                  = DCMPLX( DBLE( AP( J+( J-1 )*( 2*N-J ) / 2 ) ),
+     $                  0.0D+0 )
+  100             CONTINUE
                END IF
             END IF
          END IF
@@ -544,11 +638,11 @@
 *
          K = K + KSTEP
          KC = KNC + N - K + 2
-         GO TO 40
+         GO TO 60
 *
       END IF
 *
-   70 CONTINUE
+  110 CONTINUE
       RETURN
 *
 *     End of ZHPTRF
