@@ -1,11 +1,368 @@
+*> \brief \b DDRGSX
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE DDRGSX( NSIZE, NCMAX, THRESH, NIN, NOUT, A, LDA, B, AI,
+*                          BI, Z, Q, ALPHAR, ALPHAI, BETA, C, LDC, S,
+*                          WORK, LWORK, IWORK, LIWORK, BWORK, INFO )
+* 
+*       .. Scalar Arguments ..
+*       INTEGER            INFO, LDA, LDC, LIWORK, LWORK, NCMAX, NIN,
+*      $                   NOUT, NSIZE
+*       DOUBLE PRECISION   THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            BWORK( * )
+*       INTEGER            IWORK( * )
+*       DOUBLE PRECISION   A( LDA, * ), AI( LDA, * ), ALPHAI( * ),
+*      $                   ALPHAR( * ), B( LDA, * ), BETA( * ),
+*      $                   BI( LDA, * ), C( LDC, * ), Q( LDA, * ), S( * ),
+*      $                   WORK( * ), Z( LDA, * )
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> DDRGSX checks the nonsymmetric generalized eigenvalue (Schur form)
+*> problem expert driver DGGESX.
+*>
+*> DGGESX factors A and B as Q S Z' and Q T Z', where ' means
+*> transpose, T is upper triangular, S is in generalized Schur form
+*> (block upper triangular, with 1x1 and 2x2 blocks on the diagonal,
+*> the 2x2 blocks corresponding to complex conjugate pairs of
+*> generalized eigenvalues), and Q and Z are orthogonal.  It also
+*> computes the generalized eigenvalues (alpha(1),beta(1)), ...,
+*> (alpha(n),beta(n)). Thus, w(j) = alpha(j)/beta(j) is a root of the
+*> characteristic equation
+*>
+*>     det( A - w(j) B ) = 0
+*>
+*> Optionally it also reorders the eigenvalues so that a selected
+*> cluster of eigenvalues appears in the leading diagonal block of the
+*> Schur forms; computes a reciprocal condition number for the average
+*> of the selected eigenvalues; and computes a reciprocal condition
+*> number for the right and left deflating subspaces corresponding to
+*> the selected eigenvalues.
+*>
+*> When DDRGSX is called with NSIZE > 0, five (5) types of built-in
+*> matrix pairs are used to test the routine DGGESX.
+*>
+*> When DDRGSX is called with NSIZE = 0, it reads in test matrix data
+*> to test DGGESX.
+*>
+*> For each matrix pair, the following tests will be performed and
+*> compared with the threshhold THRESH except for the tests (7) and (9):
+*>
+*> (1)   | A - Q S Z' | / ( |A| n ulp )
+*>
+*> (2)   | B - Q T Z' | / ( |B| n ulp )
+*>
+*> (3)   | I - QQ' | / ( n ulp )
+*>
+*> (4)   | I - ZZ' | / ( n ulp )
+*>
+*> (5)   if A is in Schur form (i.e. quasi-triangular form)
+*>
+*> (6)   maximum over j of D(j)  where:
+*>
+*>       if alpha(j) is real:
+*>                     |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|
+*>           D(j) = ------------------------ + -----------------------
+*>                  max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)
+*>
+*>       if alpha(j) is complex:
+*>                                 | det( s S - w T ) |
+*>           D(j) = ---------------------------------------------------
+*>                  ulp max( s norm(S), |w| norm(T) )*norm( s S - w T )
+*>
+*>           and S and T are here the 2 x 2 diagonal blocks of S and T
+*>           corresponding to the j-th and j+1-th eigenvalues.
+*>
+*> (7)   if sorting worked and SDIM is the number of eigenvalues
+*>       which were selected.
+*>
+*> (8)   the estimated value DIF does not differ from the true values of
+*>       Difu and Difl more than a factor 10*THRESH. If the estimate DIF
+*>       equals zero the corresponding true values of Difu and Difl
+*>       should be less than EPS*norm(A, B). If the true value of Difu
+*>       and Difl equal zero, the estimate DIF should be less than
+*>       EPS*norm(A, B).
+*>
+*> (9)   If INFO = N+3 is returned by DGGESX, the reordering "failed"
+*>       and we check that DIF = PL = PR = 0 and that the true value of
+*>       Difu and Difl is < EPS*norm(A, B). We count the events when
+*>       INFO=N+3.
+*>
+*> For read-in test matrices, the above tests are run except that the
+*> exact value for DIF (and PL) is input data.  Additionally, there is
+*> one more test run for read-in test matrices:
+*>
+*> (10)  the estimated value PL does not differ from the true value of
+*>       PLTRU more than a factor THRESH. If the estimate PL equals
+*>       zero the corresponding true value of PLTRU should be less than
+*>       EPS*norm(A, B). If the true value of PLTRU equal zero, the
+*>       estimate PL should be less than EPS*norm(A, B).
+*>
+*> Note that for the built-in tests, a total of 10*NSIZE*(NSIZE-1)
+*> matrix pairs are generated and tested. NSIZE should be kept small.
+*>
+*> SVD (routine DGESVD) is used for computing the true value of DIF_u
+*> and DIF_l when testing the built-in test problems.
+*>
+*> Built-in Test Matrices
+*> ======================
+*>
+*> All built-in test matrices are the 2 by 2 block of triangular
+*> matrices
+*>
+*>          A = [ A11 A12 ]    and      B = [ B11 B12 ]
+*>              [     A22 ]                 [     B22 ]
+*>
+*> where for different type of A11 and A22 are given as the following.
+*> A12 and B12 are chosen so that the generalized Sylvester equation
+*>
+*>          A11*R - L*A22 = -A12
+*>          B11*R - L*B22 = -B12
+*>
+*> have prescribed solution R and L.
+*>
+*> Type 1:  A11 = J_m(1,-1) and A_22 = J_k(1-a,1).
+*>          B11 = I_m, B22 = I_k
+*>          where J_k(a,b) is the k-by-k Jordan block with ``a'' on
+*>          diagonal and ``b'' on superdiagonal.
+*>
+*> Type 2:  A11 = (a_ij) = ( 2(.5-sin(i)) ) and
+*>          B11 = (b_ij) = ( 2(.5-sin(ij)) ) for i=1,...,m, j=i,...,m
+*>          A22 = (a_ij) = ( 2(.5-sin(i+j)) ) and
+*>          B22 = (b_ij) = ( 2(.5-sin(ij)) ) for i=m+1,...,k, j=i,...,k
+*>
+*> Type 3:  A11, A22 and B11, B22 are chosen as for Type 2, but each
+*>          second diagonal block in A_11 and each third diagonal block
+*>          in A_22 are made as 2 by 2 blocks.
+*>
+*> Type 4:  A11 = ( 20(.5 - sin(ij)) ) and B22 = ( 2(.5 - sin(i+j)) )
+*>             for i=1,...,m,  j=1,...,m and
+*>          A22 = ( 20(.5 - sin(i+j)) ) and B22 = ( 2(.5 - sin(ij)) )
+*>             for i=m+1,...,k,  j=m+1,...,k
+*>
+*> Type 5:  (A,B) and have potentially close or common eigenvalues and
+*>          very large departure from block diagonality A_11 is chosen
+*>          as the m x m leading submatrix of A_1:
+*>                  |  1  b                            |
+*>                  | -b  1                            |
+*>                  |        1+d  b                    |
+*>                  |         -b 1+d                   |
+*>           A_1 =  |                  d  1            |
+*>                  |                 -1  d            |
+*>                  |                        -d  1     |
+*>                  |                        -1 -d     |
+*>                  |                               1  |
+*>          and A_22 is chosen as the k x k leading submatrix of A_2:
+*>                  | -1  b                            |
+*>                  | -b -1                            |
+*>                  |       1-d  b                     |
+*>                  |       -b  1-d                    |
+*>           A_2 =  |                 d 1+b            |
+*>                  |               -1-b d             |
+*>                  |                       -d  1+b    |
+*>                  |                      -1+b  -d    |
+*>                  |                              1-d |
+*>          and matrix B are chosen as identity matrices (see DLATM5).
+*>
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] NSIZE
+*> \verbatim
+*>          NSIZE is INTEGER
+*>          The maximum size of the matrices to use. NSIZE >= 0.
+*>          If NSIZE = 0, no built-in tests matrices are used, but
+*>          read-in test matrices are used to test DGGESX.
+*> \endverbatim
+*>
+*> \param[in] NCMAX
+*> \verbatim
+*>          NCMAX is INTEGER
+*>          Maximum allowable NMAX for generating Kroneker matrix
+*>          in call to DLAKF2
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is DOUBLE PRECISION
+*>          A test will count as "failed" if the "error", computed as
+*>          described above, exceeds THRESH.  Note that the error
+*>          is scaled to be O(1), so THRESH should be a reasonably
+*>          small multiple of 1, e.g., 10 or 100.  In particular,
+*>          it should not depend on the precision (single vs. double)
+*>          or the size of the matrix.  THRESH >= 0.
+*> \endverbatim
+*>
+*> \param[in] NIN
+*> \verbatim
+*>          NIN is INTEGER
+*>          The FORTRAN unit number for reading in the data file of
+*>          problems to solve.
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The FORTRAN unit number for printing out error messages
+*>          (e.g., if a routine returns IINFO not equal to 0.)
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is DOUBLE PRECISION array, dimension (LDA, NSIZE)
+*>          Used to store the matrix whose eigenvalues are to be
+*>          computed.  On exit, A contains the last matrix actually used.
+*> \endverbatim
+*>
+*> \param[in] LDA
+*> \verbatim
+*>          LDA is INTEGER
+*>          The leading dimension of A, B, AI, BI, Z and Q,
+*>          LDA >= max( 1, NSIZE ). For the read-in test,
+*>          LDA >= max( 1, N ), N is the size of the test matrices.
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is DOUBLE PRECISION array, dimension (LDA, NSIZE)
+*>          Used to store the matrix whose eigenvalues are to be
+*>          computed.  On exit, B contains the last matrix actually used.
+*> \endverbatim
+*>
+*> \param[out] AI
+*> \verbatim
+*>          AI is DOUBLE PRECISION array, dimension (LDA, NSIZE)
+*>          Copy of A, modified by DGGESX.
+*> \endverbatim
+*>
+*> \param[out] BI
+*> \verbatim
+*>          BI is DOUBLE PRECISION array, dimension (LDA, NSIZE)
+*>          Copy of B, modified by DGGESX.
+*> \endverbatim
+*>
+*> \param[out] Z
+*> \verbatim
+*>          Z is DOUBLE PRECISION array, dimension (LDA, NSIZE)
+*>          Z holds the left Schur vectors computed by DGGESX.
+*> \endverbatim
+*>
+*> \param[out] Q
+*> \verbatim
+*>          Q is DOUBLE PRECISION array, dimension (LDA, NSIZE)
+*>          Q holds the right Schur vectors computed by DGGESX.
+*> \endverbatim
+*>
+*> \param[out] ALPHAR
+*> \verbatim
+*>          ALPHAR is DOUBLE PRECISION array, dimension (NSIZE)
+*> \endverbatim
+*>
+*> \param[out] ALPHAI
+*> \verbatim
+*>          ALPHAI is DOUBLE PRECISION array, dimension (NSIZE)
+*> \endverbatim
+*>
+*> \param[out] BETA
+*> \verbatim
+*>          BETA is DOUBLE PRECISION array, dimension (NSIZE)
+*>
+*>          On exit, (ALPHAR + ALPHAI*i)/BETA are the eigenvalues.
+*> \endverbatim
+*>
+*> \param[out] C
+*> \verbatim
+*>          C is DOUBLE PRECISION array, dimension (LDC, LDC)
+*>          Store the matrix generated by subroutine DLAKF2, this is the
+*>          matrix formed by Kronecker products used for estimating
+*>          DIF.
+*> \endverbatim
+*>
+*> \param[in] LDC
+*> \verbatim
+*>          LDC is INTEGER
+*>          The leading dimension of C. LDC >= max(1, LDA*LDA/2 ).
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is DOUBLE PRECISION array, dimension (LDC)
+*>          Singular values of C
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is DOUBLE PRECISION array, dimension (LWORK)
+*> \endverbatim
+*>
+*> \param[in] LWORK
+*> \verbatim
+*>          LWORK is INTEGER
+*>          The dimension of the array WORK.
+*>          LWORK >= MAX( 5*NSIZE*NSIZE/2 - 2, 10*(NSIZE+1) )
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (LIWORK)
+*> \endverbatim
+*>
+*> \param[in] LIWORK
+*> \verbatim
+*>          LIWORK is INTEGER
+*>          The dimension of the array IWORK. LIWORK >= NSIZE + 6.
+*> \endverbatim
+*>
+*> \param[out] BWORK
+*> \verbatim
+*>          BWORK is LOGICAL array, dimension (LDA)
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          = 0:  successful exit
+*>          < 0:  if INFO = -i, the i-th argument had an illegal value.
+*>          > 0:  A routine returned an error code.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2011
+*
+*> \ingroup double_eig
+*
+*  =====================================================================
       SUBROUTINE DDRGSX( NSIZE, NCMAX, THRESH, NIN, NOUT, A, LDA, B, AI,
      $                   BI, Z, Q, ALPHAR, ALPHAI, BETA, C, LDC, S,
      $                   WORK, LWORK, IWORK, LIWORK, BWORK, INFO )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine (version 3.4.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2011
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDC, LIWORK, LWORK, NCMAX, NIN,
@@ -21,243 +378,6 @@
      $                   WORK( * ), Z( LDA, * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  DDRGSX checks the nonsymmetric generalized eigenvalue (Schur form)
-*  problem expert driver DGGESX.
-*
-*  DGGESX factors A and B as Q S Z' and Q T Z', where ' means
-*  transpose, T is upper triangular, S is in generalized Schur form
-*  (block upper triangular, with 1x1 and 2x2 blocks on the diagonal,
-*  the 2x2 blocks corresponding to complex conjugate pairs of
-*  generalized eigenvalues), and Q and Z are orthogonal.  It also
-*  computes the generalized eigenvalues (alpha(1),beta(1)), ...,
-*  (alpha(n),beta(n)). Thus, w(j) = alpha(j)/beta(j) is a root of the
-*  characteristic equation
-*
-*      det( A - w(j) B ) = 0
-*
-*  Optionally it also reorders the eigenvalues so that a selected
-*  cluster of eigenvalues appears in the leading diagonal block of the
-*  Schur forms; computes a reciprocal condition number for the average
-*  of the selected eigenvalues; and computes a reciprocal condition
-*  number for the right and left deflating subspaces corresponding to
-*  the selected eigenvalues.
-*
-*  When DDRGSX is called with NSIZE > 0, five (5) types of built-in
-*  matrix pairs are used to test the routine DGGESX.
-*
-*  When DDRGSX is called with NSIZE = 0, it reads in test matrix data
-*  to test DGGESX.
-*
-*  For each matrix pair, the following tests will be performed and
-*  compared with the threshhold THRESH except for the tests (7) and (9):
-*
-*  (1)   | A - Q S Z' | / ( |A| n ulp )
-*
-*  (2)   | B - Q T Z' | / ( |B| n ulp )
-*
-*  (3)   | I - QQ' | / ( n ulp )
-*
-*  (4)   | I - ZZ' | / ( n ulp )
-*
-*  (5)   if A is in Schur form (i.e. quasi-triangular form)
-*
-*  (6)   maximum over j of D(j)  where:
-*
-*        if alpha(j) is real:
-*                      |alpha(j) - S(j,j)|        |beta(j) - T(j,j)|
-*            D(j) = ------------------------ + -----------------------
-*                   max(|alpha(j)|,|S(j,j)|)   max(|beta(j)|,|T(j,j)|)
-*
-*        if alpha(j) is complex:
-*                                  | det( s S - w T ) |
-*            D(j) = ---------------------------------------------------
-*                   ulp max( s norm(S), |w| norm(T) )*norm( s S - w T )
-*
-*            and S and T are here the 2 x 2 diagonal blocks of S and T
-*            corresponding to the j-th and j+1-th eigenvalues.
-*
-*  (7)   if sorting worked and SDIM is the number of eigenvalues
-*        which were selected.
-*
-*  (8)   the estimated value DIF does not differ from the true values of
-*        Difu and Difl more than a factor 10*THRESH. If the estimate DIF
-*        equals zero the corresponding true values of Difu and Difl
-*        should be less than EPS*norm(A, B). If the true value of Difu
-*        and Difl equal zero, the estimate DIF should be less than
-*        EPS*norm(A, B).
-*
-*  (9)   If INFO = N+3 is returned by DGGESX, the reordering "failed"
-*        and we check that DIF = PL = PR = 0 and that the true value of
-*        Difu and Difl is < EPS*norm(A, B). We count the events when
-*        INFO=N+3.
-*
-*  For read-in test matrices, the above tests are run except that the
-*  exact value for DIF (and PL) is input data.  Additionally, there is
-*  one more test run for read-in test matrices:
-*
-*  (10)  the estimated value PL does not differ from the true value of
-*        PLTRU more than a factor THRESH. If the estimate PL equals
-*        zero the corresponding true value of PLTRU should be less than
-*        EPS*norm(A, B). If the true value of PLTRU equal zero, the
-*        estimate PL should be less than EPS*norm(A, B).
-*
-*  Note that for the built-in tests, a total of 10*NSIZE*(NSIZE-1)
-*  matrix pairs are generated and tested. NSIZE should be kept small.
-*
-*  SVD (routine DGESVD) is used for computing the true value of DIF_u
-*  and DIF_l when testing the built-in test problems.
-*
-*  Built-in Test Matrices
-*  ======================
-*
-*  All built-in test matrices are the 2 by 2 block of triangular
-*  matrices
-*
-*           A = [ A11 A12 ]    and      B = [ B11 B12 ]
-*               [     A22 ]                 [     B22 ]
-*
-*  where for different type of A11 and A22 are given as the following.
-*  A12 and B12 are chosen so that the generalized Sylvester equation
-*
-*           A11*R - L*A22 = -A12
-*           B11*R - L*B22 = -B12
-*
-*  have prescribed solution R and L.
-*
-*  Type 1:  A11 = J_m(1,-1) and A_22 = J_k(1-a,1).
-*           B11 = I_m, B22 = I_k
-*           where J_k(a,b) is the k-by-k Jordan block with ``a'' on
-*           diagonal and ``b'' on superdiagonal.
-*
-*  Type 2:  A11 = (a_ij) = ( 2(.5-sin(i)) ) and
-*           B11 = (b_ij) = ( 2(.5-sin(ij)) ) for i=1,...,m, j=i,...,m
-*           A22 = (a_ij) = ( 2(.5-sin(i+j)) ) and
-*           B22 = (b_ij) = ( 2(.5-sin(ij)) ) for i=m+1,...,k, j=i,...,k
-*
-*  Type 3:  A11, A22 and B11, B22 are chosen as for Type 2, but each
-*           second diagonal block in A_11 and each third diagonal block
-*           in A_22 are made as 2 by 2 blocks.
-*
-*  Type 4:  A11 = ( 20(.5 - sin(ij)) ) and B22 = ( 2(.5 - sin(i+j)) )
-*              for i=1,...,m,  j=1,...,m and
-*           A22 = ( 20(.5 - sin(i+j)) ) and B22 = ( 2(.5 - sin(ij)) )
-*              for i=m+1,...,k,  j=m+1,...,k
-*
-*  Type 5:  (A,B) and have potentially close or common eigenvalues and
-*           very large departure from block diagonality A_11 is chosen
-*           as the m x m leading submatrix of A_1:
-*                   |  1  b                            |
-*                   | -b  1                            |
-*                   |        1+d  b                    |
-*                   |         -b 1+d                   |
-*            A_1 =  |                  d  1            |
-*                   |                 -1  d            |
-*                   |                        -d  1     |
-*                   |                        -1 -d     |
-*                   |                               1  |
-*           and A_22 is chosen as the k x k leading submatrix of A_2:
-*                   | -1  b                            |
-*                   | -b -1                            |
-*                   |       1-d  b                     |
-*                   |       -b  1-d                    |
-*            A_2 =  |                 d 1+b            |
-*                   |               -1-b d             |
-*                   |                       -d  1+b    |
-*                   |                      -1+b  -d    |
-*                   |                              1-d |
-*           and matrix B are chosen as identity matrices (see DLATM5).
-*
-*
-*  Arguments
-*  =========
-*
-*  NSIZE   (input) INTEGER
-*          The maximum size of the matrices to use. NSIZE >= 0.
-*          If NSIZE = 0, no built-in tests matrices are used, but
-*          read-in test matrices are used to test DGGESX.
-*
-*  NCMAX   (input) INTEGER
-*          Maximum allowable NMAX for generating Kroneker matrix
-*          in call to DLAKF2
-*
-*  THRESH  (input) DOUBLE PRECISION
-*          A test will count as "failed" if the "error", computed as
-*          described above, exceeds THRESH.  Note that the error
-*          is scaled to be O(1), so THRESH should be a reasonably
-*          small multiple of 1, e.g., 10 or 100.  In particular,
-*          it should not depend on the precision (single vs. double)
-*          or the size of the matrix.  THRESH >= 0.
-*
-*  NIN     (input) INTEGER
-*          The FORTRAN unit number for reading in the data file of
-*          problems to solve.
-*
-*  NOUT    (input) INTEGER
-*          The FORTRAN unit number for printing out error messages
-*          (e.g., if a routine returns IINFO not equal to 0.)
-*
-*  A       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)
-*          Used to store the matrix whose eigenvalues are to be
-*          computed.  On exit, A contains the last matrix actually used.
-*
-*  LDA     (input) INTEGER
-*          The leading dimension of A, B, AI, BI, Z and Q,
-*          LDA >= max( 1, NSIZE ). For the read-in test,
-*          LDA >= max( 1, N ), N is the size of the test matrices.
-*
-*  B       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)
-*          Used to store the matrix whose eigenvalues are to be
-*          computed.  On exit, B contains the last matrix actually used.
-*
-*  AI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)
-*          Copy of A, modified by DGGESX.
-*
-*  BI      (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)
-*          Copy of B, modified by DGGESX.
-*
-*  Z       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)
-*          Z holds the left Schur vectors computed by DGGESX.
-*
-*  Q       (workspace) DOUBLE PRECISION array, dimension (LDA, NSIZE)
-*          Q holds the right Schur vectors computed by DGGESX.
-*
-*  ALPHAR  (workspace) DOUBLE PRECISION array, dimension (NSIZE)
-*  ALPHAI  (workspace) DOUBLE PRECISION array, dimension (NSIZE)
-*  BETA    (workspace) DOUBLE PRECISION array, dimension (NSIZE)
-*          On exit, (ALPHAR + ALPHAI*i)/BETA are the eigenvalues.
-*
-*  C       (workspace) DOUBLE PRECISION array, dimension (LDC, LDC)
-*          Store the matrix generated by subroutine DLAKF2, this is the
-*          matrix formed by Kronecker products used for estimating
-*          DIF.
-*
-*  LDC     (input) INTEGER
-*          The leading dimension of C. LDC >= max(1, LDA*LDA/2 ).
-*
-*  S       (workspace) DOUBLE PRECISION array, dimension (LDC)
-*          Singular values of C
-*
-*  WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK)
-*
-*  LWORK   (input) INTEGER
-*          The dimension of the array WORK.
-*          LWORK >= MAX( 5*NSIZE*NSIZE/2 - 2, 10*(NSIZE+1) )
-*
-*  IWORK   (workspace) INTEGER array, dimension (LIWORK)
-*
-*  LIWORK  (input) INTEGER
-*          The dimension of the array IWORK. LIWORK >= NSIZE + 6.
-*
-*  BWORK   (workspace) LOGICAL array, dimension (LDA)
-*
-*  INFO    (output) INTEGER
-*          = 0:  successful exit
-*          < 0:  if INFO = -i, the i-th argument had an illegal value.
-*          > 0:  A routine returned an error code.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -325,7 +445,7 @@
 *
       MINWRK = 1
       IF( INFO.EQ.0 .AND. LWORK.GE.1 ) THEN
-         MINWRK = MAX( 10*( NSIZE+1 ), 5*NSIZE*NSIZE / 2-2 )
+         MINWRK = MAX( 10*( NSIZE+1 ), 5*NSIZE*NSIZE / 2 )
 *
 *        workspace for sggesx
 *
@@ -334,9 +454,9 @@
          MAXWRK = MAX( MAXWRK, 9*( NSIZE+1 )+NSIZE*
      $            ILAENV( 1, 'DORGQR', ' ', NSIZE, 1, NSIZE, -1 ) )
 *
-*        workspace for sgesvd
+*        workspace for dgesvd
 *
-         BDSPAC = MAX( 3*NSIZE*NSIZE / 2, 5*NSIZE*NSIZE / 2-2 )
+         BDSPAC = 5*NSIZE*NSIZE / 2
          MAXWRK = MAX( MAXWRK, 3*NSIZE*NSIZE / 2+NSIZE*NSIZE*
      $            ILAENV( 1, 'DGEBRD', ' ', NSIZE*NSIZE / 2,
      $            NSIZE*NSIZE / 2, -1, -1 ) )
@@ -368,6 +488,7 @@
 *
 *     Go to the tests for read-in matrix pairs
 *
+      IFUNC = 0
       IF( NSIZE.EQ.0 )
      $   GO TO 70
 *
@@ -590,7 +711,7 @@
 *                       print a header to the data file.
 *
                         IF( NERRS.EQ.0 ) THEN
-                           WRITE( NOUT, FMT = 9995 )'SGX'
+                           WRITE( NOUT, FMT = 9995 )'DGX'
 *
 *                          Matrix types
 *
@@ -807,7 +928,7 @@
 *           print a header to the data file.
 *
             IF( NERRS.EQ.0 ) THEN
-               WRITE( NOUT, FMT = 9995 )'SGX'
+               WRITE( NOUT, FMT = 9995 )'DGX'
 *
 *              Matrix types
 *
@@ -837,7 +958,7 @@
 *
 *     Summary
 *
-      CALL ALASVM( 'SGX', NOUT, NERRS, NTESTT, 0 )
+      CALL ALASVM( 'DGX', NOUT, NERRS, NTESTT, 0 )
 *
       WORK( 1 ) = MAXWRK
 *
@@ -890,10 +1011,10 @@
      $      ' 10 = 1/ULP  if PLEST/PLTRU > THRESH or ',
      $      'PLTRU/PLEST > THRESH', /
      $      '    ( Test 10 is only for input examples )', / )
- 9991 FORMAT( ' Matrix order=', I2, ', type=', I2, ', a=', D10.4,
+ 9991 FORMAT( ' Matrix order=', I2, ', type=', I2, ', a=', D10.3,
      $      ', order(A_11)=', I2, ', result ', I2, ' is ', 0P, F8.2 )
- 9990 FORMAT( ' Matrix order=', I2, ', type=', I2, ', a=', D10.4,
-     $      ', order(A_11)=', I2, ', result ', I2, ' is ', 0P, D10.4 )
+ 9990 FORMAT( ' Matrix order=', I2, ', type=', I2, ', a=', D10.3,
+     $      ', order(A_11)=', I2, ', result ', I2, ' is ', 0P, D10.3 )
  9989 FORMAT( ' Input example #', I2, ', matrix order=', I4, ',',
      $      ' result ', I2, ' is', 0P, F8.2 )
  9988 FORMAT( ' Input example #', I2, ', matrix order=', I4, ',',
