@@ -1,57 +1,100 @@
+*> \brief \b SERRBD
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SERRBD( PATH, NUNIT )
+* 
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            NUNIT
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SERRBD tests the error exits for SGEBD2, SGEBRD, SORGBR, SORMBR, 
+*> SBDSQR, SBDSDC and SBDSVDX.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The LAPACK path name for the routines to be tested.
+*> \endverbatim
+*>
+*> \param[in] NUNIT
+*> \verbatim
+*>          NUNIT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2015
+*
+*> \ingroup single_eig
+*
+*  =====================================================================
       SUBROUTINE SERRBD( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SERRBD tests the error exits for SGEBRD, SORGBR, SORMBR, SBDSQR and
-*  SBDSDC.
-*
-*  Arguments
-*  =========
-*
-*  PATH    (input) CHARACTER*3
-*          The LAPACK path name for the routines to be tested.
-*
-*  NUNIT   (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            NMAX, LW
       PARAMETER          ( NMAX = 4, LW = NMAX )
+      REAL               ZERO, ONE
+      PARAMETER          ( ZERO = 0.0E0, ONE = 1.0E0 )
 *     ..
 *     .. Local Scalars ..
       CHARACTER*2        C2
-      INTEGER            I, INFO, J, NT
+      INTEGER            I, INFO, J, NS, NT
 *     ..
 *     .. Local Arrays ..
       INTEGER            IQ( NMAX, NMAX ), IW( NMAX )
       REAL               A( NMAX, NMAX ), D( NMAX ), E( NMAX ),
-     $                   Q( NMAX, NMAX ), TP( NMAX ), TQ( NMAX ),
-     $                   U( NMAX, NMAX ), V( NMAX, NMAX ), W( LW )
+     $                   Q( NMAX, NMAX ), S( NMAX ), TP( NMAX ), 
+     $                   TQ( NMAX ), U( NMAX, NMAX ), 
+     $                   V( NMAX, NMAX ), W( LW )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAMEN
       EXTERNAL           LSAMEN
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CHKXER, SBDSDC, SBDSQR, SGEBD2, SGEBRD, SORGBR,
+      EXTERNAL           CHKXER, SBDSDC, SBDSQR, SBDSVDX, SGEBD2, SGEBRD, SORGBR,
      $                   SORMBR
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NOUT
 *     ..
 *     .. Common blocks ..
@@ -71,7 +114,7 @@
 *
       DO 20 J = 1, NMAX
          DO 10 I = 1, NMAX
-            A( I, J ) = 1. / REAL( I+J )
+            A( I, J ) = 1.D0 / REAL( I+J )
    10    CONTINUE
    20 CONTINUE
       OK = .TRUE.
@@ -261,6 +304,59 @@
      $                INFO )
          CALL CHKXER( 'SBDSDC', INFOT, NOUT, LERR, OK )
          NT = NT + 5
+*
+*        SBDSVDX
+*
+         SRNAMT = 'SBDSVDX'
+         INFOT = 1
+         CALL SBDSVDX( 'X', 'N', 'A', 1, D, E, ZERO, ONE, 0, 0, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL SBDSVDX( 'U', 'X', 'A', 1, D, E, ZERO, ONE, 0, 0, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL SBDSVDX( 'U', 'V', 'X', 1, D, E, ZERO, ONE, 0, 0, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL SBDSVDX( 'U', 'V', 'A', -1, D, E, ZERO, ONE, 0, 0, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL SBDSVDX( 'U', 'V', 'V', 2, D, E, -ONE, ZERO, 0, 0, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 8
+         CALL SBDSVDX( 'U', 'V', 'V', 2, D, E, ONE, ZERO, 0, 0, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 9
+         CALL SBDSVDX( 'L', 'V', 'I', 2, D, E, ZERO, ZERO, 0, 2, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 9
+         CALL SBDSVDX( 'L', 'V', 'I', 4, D, E, ZERO, ZERO, 5, 2, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 10
+         CALL SBDSVDX( 'L', 'V', 'I', 4, D, E, ZERO, ZERO, 3, 2, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 10
+         CALL SBDSVDX( 'L', 'V', 'I', 4, D, E, ZERO, ZERO, 3, 5, 
+     $                    NS, S, Q, 1, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 14
+         CALL SBDSVDX( 'L', 'V', 'A', 4, D, E, ZERO, ZERO, 0, 0, 
+     $                    NS, S, Q, 0, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 14
+         CALL SBDSVDX( 'L', 'V', 'A', 4, D, E, ZERO, ZERO, 0, 0, 
+     $                    NS, S, Q, 2, W, IW, INFO)
+         CALL CHKXER( 'SBDSVDX', INFOT, NOUT, LERR, OK )
+         NT = NT + 12
       END IF
 *
 *     Print a summary line.
