@@ -1,40 +1,83 @@
+*> \brief \b SERRED
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SERRED( PATH, NUNIT )
+* 
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            NUNIT
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SERRED tests the error exits for the eigenvalue driver routines for
+*> REAL matrices:
+*>
+*> PATH  driver   description
+*> ----  ------   -----------
+*> SEV   SGEEV    find eigenvalues/eigenvectors for nonsymmetric A
+*> SES   SGEES    find eigenvalues/Schur form for nonsymmetric A
+*> SVX   SGEEVX   SGEEV + balancing and condition estimation
+*> SSX   SGEESX   SGEES + balancing and condition estimation
+*> SBD   SGESVD   compute SVD of an M-by-N matrix A
+*>       SGESDD   compute SVD of an M-by-N matrix A (by divide and
+*>                conquer)
+*>       SGEJSV   compute SVD of an M-by-N matrix A where M >= N
+*>       SGESVDX  compute SVD of an M-by-N matrix A(by bisection
+*>                and inverse iteration)
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The LAPACK path name for the routines to be tested.
+*> \endverbatim
+*>
+*> \param[in] NUNIT
+*> \verbatim
+*>          NUNIT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2015
+*
+*> \ingroup single_eig
+*
+*  =====================================================================
       SUBROUTINE SERRED( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SERRED tests the error exits for the eigenvalue driver routines for
-*  REAL matrices:
-*
-*  PATH  driver   description
-*  ----  ------   -----------
-*  SEV   SGEEV    find eigenvalues/eigenvectors for nonsymmetric A
-*  SES   SGEES    find eigenvalues/Schur form for nonsymmetric A
-*  SVX   SGEEVX   SGEEV + balancing and condition estimation
-*  SSX   SGEESX   SGEES + balancing and condition estimation
-*  SBD   SGESVD   compute SVD of an M-by-N matrix A
-*        SGESDD   compute SVD of an M-by-N matrix A (by divide and
-*                 conquer)
-*
-*  Arguments
-*  =========
-*
-*  PATH    (input) CHARACTER*3
-*          The LAPACK path name for the routines to be tested.
-*
-*  NUNIT   (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -44,7 +87,7 @@
 *     ..
 *     .. Local Scalars ..
       CHARACTER*2        C2
-      INTEGER            I, IHI, ILO, INFO, J, NT, SDIM
+      INTEGER            I, IHI, ILO, INFO, J, NS, NT, SDIM
       REAL               ABNRM
 *     ..
 *     .. Local Arrays ..
@@ -53,15 +96,18 @@
       REAL               A( NMAX, NMAX ), R1( NMAX ), R2( NMAX ),
      $                   S( NMAX ), U( NMAX, NMAX ), VL( NMAX, NMAX ),
      $                   VR( NMAX, NMAX ), VT( NMAX, NMAX ),
-     $                   W( 4*NMAX ), WI( NMAX ), WR( NMAX )
+     $                   W( 10*NMAX ), WI( NMAX ), WR( NMAX )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CHKXER, SGEES, SGEESX, SGEEV, SGEEVX, SGESDD,
-     $                   SGESVD
+      EXTERNAL           CHKXER, SGEES, SGEESX, SGEEV, SGEEVX, SGEJSV,
+     $                   SGESDD, SGESVD
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAMEN, SSLECT
-      EXTERNAL           LSAMEN, SSLECT
+      LOGICAL            SSLECT, LSAMEN
+      EXTERNAL           SSLECT, LSAMEN
+*     ..
+*     .. Intrinsic Functions ..
+      INTRINSIC          LEN_TRIM
 *     ..
 *     .. Arrays in Common ..
       LOGICAL            SELVAL( 20 )
@@ -69,7 +115,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NOUT, SELDIM, SELOPT
 *     ..
 *     .. Common blocks ..
@@ -279,9 +325,10 @@
          INFOT = 11
          CALL SGESVD( 'N', 'A', 1, 2, A, 1, S, U, 1, VT, 1, W, 5, INFO )
          CALL CHKXER( 'SGESVD', INFOT, NOUT, LERR, OK )
-         NT = NT + 8
+         NT = 8
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
@@ -307,9 +354,135 @@
          INFOT = 10
          CALL SGESDD( 'A', 1, 2, A, 1, S, U, 1, VT, 1, W, 5, IW, INFO )
          CALL CHKXER( 'SGESDD', INFOT, NOUT, LERR, OK )
-         NT = NT - 2
+         NT = 6
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
+         ELSE
+            WRITE( NOUT, FMT = 9998 )
+         END IF
+*
+*        Test SGEJSV
+*
+         SRNAMT = 'SGEJSV'
+         INFOT = 1
+         CALL SGEJSV( 'X', 'U', 'V', 'R', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL SGEJSV( 'G', 'X', 'V', 'R', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL SGEJSV( 'G', 'U', 'X', 'R', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL SGEJSV( 'G', 'U', 'V', 'X', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 5
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'X', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 6
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'X',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 -1, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 8
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 0, -1, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 10
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 2, 1, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 13
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 2, 2, A, 2, S, U, 1, VT, 2,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 14
+         CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 2, 2, A, 2, S, U, 2, VT, 1,
+     $                 W, 1, IW, INFO)
+         CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
+         NT = 11
+         IF( OK ) THEN
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
+         ELSE
+            WRITE( NOUT, FMT = 9998 )
+         END IF
+*
+*        Test SGESVDX
+*
+         SRNAMT = 'SGESVDX'
+         INFOT = 1
+         CALL SGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL SGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL SGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL SGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 5
+         CALL SGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL SGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 8
+         CALL SGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 9
+         CALL SGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 10
+         CALL SGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+     $                 0, 1, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 11
+         CALL SGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+     $                 1, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 15
+         CALL SGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 16
+         CALL SGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
+         CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
+         NT = 12
+         IF( OK ) THEN
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
@@ -319,16 +492,18 @@
 *
       IF( .NOT.LSAMEN( 2, C2, 'BD' ) ) THEN
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
       END IF
 *
- 9999 FORMAT( 1X, A6, ' passed the tests of the error exits (', I3,
+ 9999 FORMAT( 1X, A, ' passed the tests of the error exits (', I3,
      $      ' tests done)' )
- 9998 FORMAT( ' *** ', A6, ' failed the tests of the error exits ***' )
+ 9998 FORMAT( ' *** ', A, ' failed the tests of the error exits ***' )
       RETURN
 *
 *     End of SERRED
+*
       END
