@@ -1,40 +1,83 @@
+*> \brief \b ZERRED
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ZERRED( PATH, NUNIT )
+* 
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            NUNIT
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ZERRED tests the error exits for the eigenvalue driver routines for
+*> DOUBLE COMPLEX PRECISION matrices:
+*>
+*> PATH  driver   description
+*> ----  ------   -----------
+*> ZEV   ZGEEV    find eigenvalues/eigenvectors for nonsymmetric A
+*> ZES   ZGEES    find eigenvalues/Schur form for nonsymmetric A
+*> ZVX   ZGEEVX   ZGEEV + balancing and condition estimation
+*> ZSX   ZGEESX   ZGEES + balancing and condition estimation
+*> ZBD   ZGESVD   compute SVD of an M-by-N matrix A
+*>       ZGESDD   compute SVD of an M-by-N matrix A(by divide and
+*>                conquer)
+*>       ZGEJSV   compute SVD of an M-by-N matrix A where M >= N
+*>       ZGESVDX  compute SVD of an M-by-N matrix A(by bisection
+*>                and inverse iteration)
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The LAPACK path name for the routines to be tested.
+*> \endverbatim
+*>
+*> \param[in] NUNIT
+*> \verbatim
+*>          NUNIT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2015
+*
+*> \ingroup complex16_eig
+*
+*  =====================================================================
       SUBROUTINE ZERRED( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ZERRED tests the error exits for the eigenvalue driver routines for
-*  DOUBLE PRECISION matrices:
-*
-*  PATH  driver   description
-*  ----  ------   -----------
-*  ZEV   ZGEEV    find eigenvalues/eigenvectors for nonsymmetric A
-*  ZES   ZGEES    find eigenvalues/Schur form for nonsymmetric A
-*  ZVX   ZGEEVX   ZGEEV + balancing and condition estimation
-*  ZSX   ZGEESX   ZGEES + balancing and condition estimation
-*  ZBD   ZGESVD   compute SVD of an M-by-N matrix A
-*        ZGESDD   compute SVD of an M-by-N matrix A(by divide and
-*                 conquer)
-*
-*  Arguments
-*  =========
-*
-*  PATH    (input) CHARACTER*3
-*          The LAPACK path name for the routines to be tested.
-*
-*  NUNIT   (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -45,7 +88,7 @@
 *     ..
 *     .. Local Scalars ..
       CHARACTER*2        C2
-      INTEGER            I, IHI, ILO, INFO, J, NT, SDIM
+      INTEGER            I, IHI, ILO, INFO, J, NS, NT, SDIM
       DOUBLE PRECISION   ABNRM
 *     ..
 *     .. Local Arrays ..
@@ -54,23 +97,26 @@
       DOUBLE PRECISION   R1( NMAX ), R2( NMAX ), RW( LW ), S( NMAX )
       COMPLEX*16         A( NMAX, NMAX ), U( NMAX, NMAX ),
      $                   VL( NMAX, NMAX ), VR( NMAX, NMAX ),
-     $                   VT( NMAX, NMAX ), W( 4*NMAX ), X( NMAX )
+     $                   VT( NMAX, NMAX ), W( 10*NMAX ), X( NMAX )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CHKXER, ZGEES, ZGEESX, ZGEEV, ZGEEVX, ZGESDD,
-     $                   ZGESVD
+      EXTERNAL           CHKXER, ZGEES, ZGEESX, ZGEEV, ZGEEVX, ZGESVJ, 
+     $                   ZGESDD, ZGESVD
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAMEN, ZSLECT
       EXTERNAL           LSAMEN, ZSLECT
 *     ..
+*     .. Intrinsic Functions ..
+      INTRINSIC          LEN_TRIM
+*     ..
 *     .. Arrays in Common ..
       LOGICAL            SELVAL( 20 )
       DOUBLE PRECISION   SELWI( 20 ), SELWR( 20 )
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NOUT, SELDIM, SELOPT
 *     ..
 *     .. Common blocks ..
@@ -284,7 +330,8 @@
          CALL CHKXER( 'ZGESVD', INFOT, NOUT, LERR, OK )
          NT = NT + 8
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
@@ -318,7 +365,133 @@
          CALL CHKXER( 'ZGESDD', INFOT, NOUT, LERR, OK )
          NT = NT - 2
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
+         ELSE
+            WRITE( NOUT, FMT = 9998 )
+         END IF
+*
+*        Test ZGEJSV
+*
+         SRNAMT = 'ZGEJSV'
+         INFOT = 1
+         CALL ZGEJSV( 'X', 'U', 'V', 'R', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL ZGEJSV( 'G', 'X', 'V', 'R', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL ZGEJSV( 'G', 'U', 'X', 'R', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL ZGEJSV( 'G', 'U', 'V', 'X', 'N', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 5
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'X', 'N',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 6
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'N', 'X',
+     $                 0, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 -1, 0, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 8
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 0, -1, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 10
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 2, 1, A, 1, S, U, 1, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 13
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 2, 2, A, 2, S, U, 1, VT, 2,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         INFOT = 15
+         CALL ZGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
+     $                 2, 2, A, 2, S, U, 2, VT, 1,
+     $                 W, 1, RW, 1, IW, INFO)
+         CALL CHKXER( 'ZGEJSV', INFOT, NOUT, LERR, OK )
+         NT = 11
+         IF( OK ) THEN
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
+         ELSE
+            WRITE( NOUT, FMT = 9998 )
+         END IF
+*
+*        Test ZGESVDX
+*
+         SRNAMT = 'ZGESVDX'
+         INFOT = 1
+         CALL ZGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL ZGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL ZGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL ZGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 5
+         CALL ZGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL ZGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 8
+         CALL ZGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 9
+         CALL ZGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 10
+         CALL ZGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+     $                 0, 1, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 11
+         CALL ZGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+     $                 1, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 15
+         CALL ZGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         INFOT = 16
+         CALL ZGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO, 
+     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
+         CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
+         NT = 12
+         IF( OK ) THEN
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
@@ -328,15 +501,16 @@
 *
       IF( .NOT.LSAMEN( 2, C2, 'BD' ) ) THEN
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
       END IF
 *
- 9999 FORMAT( 1X, A6, ' passed the tests of the error exits (', I3,
+ 9999 FORMAT( 1X, A, ' passed the tests of the error exits (', I3,
      $      ' tests done)' )
- 9998 FORMAT( ' *** ', A6, ' failed the tests of the error exits ***' )
+ 9998 FORMAT( ' *** ', A, ' failed the tests of the error exits ***' )
       RETURN
 *
 *     End of ZERRED
