@@ -1,11 +1,181 @@
+*> \brief \b CDRVGB
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE CDRVGB( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, A, LA,
+*                          AFB, LAFB, ASAV, B, BSAV, X, XACT, S, WORK,
+*                          RWORK, IWORK, NOUT )
+* 
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            LA, LAFB, NN, NOUT, NRHS
+*       REAL               THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            IWORK( * ), NVAL( * )
+*       REAL               RWORK( * ), S( * )
+*       COMPLEX            A( * ), AFB( * ), ASAV( * ), B( * ), BSAV( * ),
+*      $                   WORK( * ), X( * ), XACT( * )
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> CDRVGB tests the driver routines CGBSV and -SVX.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix column dimension N.
+*> \endverbatim
+*>
+*> \param[in] NRHS
+*> \verbatim
+*>          NRHS is INTEGER
+*>          The number of right hand side vectors to be generated for
+*>          each linear system.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is REAL
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is COMPLEX array, dimension (LA)
+*> \endverbatim
+*>
+*> \param[in] LA
+*> \verbatim
+*>          LA is INTEGER
+*>          The length of the array A.  LA >= (2*NMAX-1)*NMAX
+*>          where NMAX is the largest entry in NVAL.
+*> \endverbatim
+*>
+*> \param[out] AFB
+*> \verbatim
+*>          AFB is COMPLEX array, dimension (LAFB)
+*> \endverbatim
+*>
+*> \param[in] LAFB
+*> \verbatim
+*>          LAFB is INTEGER
+*>          The length of the array AFB.  LAFB >= (3*NMAX-2)*NMAX
+*>          where NMAX is the largest entry in NVAL.
+*> \endverbatim
+*>
+*> \param[out] ASAV
+*> \verbatim
+*>          ASAV is COMPLEX array, dimension (LA)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] BSAV
+*> \verbatim
+*>          BSAV is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is REAL array, dimension (2*NMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is COMPLEX array, dimension
+*>                      (NMAX*max(3,NRHS,NMAX))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is REAL array, dimension
+*>                      (max(NMAX,2*NRHS))
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2015
+*
+*> \ingroup complex_lin
+*
+*  =====================================================================
       SUBROUTINE CDRVGB( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, A, LA,
      $                   AFB, LAFB, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2015
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -20,72 +190,6 @@
      $                   WORK( * ), X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  CDRVGB tests the driver routines CGBSV and -SVX.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix column dimension N.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) REAL
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  A       (workspace) COMPLEX array, dimension (LA)
-*
-*  LA      (input) INTEGER
-*          The length of the array A.  LA >= (2*NMAX-1)*NMAX
-*          where NMAX is the largest entry in NVAL.
-*
-*  AFB     (workspace) COMPLEX array, dimension (LAFB)
-*
-*  LAFB    (input) INTEGER
-*          The length of the array AFB.  LAFB >= (3*NMAX-2)*NMAX
-*          where NMAX is the largest entry in NVAL.
-*
-*  ASAV    (workspace) COMPLEX array, dimension (LA)
-*
-*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  BSAV    (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  S       (workspace) REAL array, dimension (2*NMAX)
-*
-*  WORK    (workspace) COMPLEX array, dimension
-*                      (NMAX*max(3,NRHS,NMAX))
-*
-*  RWORK   (workspace) REAL array, dimension
-*                      (max(NMAX,2*NRHS))
-*
-*  IWORK   (workspace) INTEGER array, dimension (NMAX)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -113,7 +217,7 @@
 *     .. Local Arrays ..
       CHARACTER          EQUEDS( 4 ), FACTS( 3 ), TRANSS( NTRAN )
       INTEGER            ISEED( 4 ), ISEEDY( 4 )
-      REAL               RESULT( NTESTS )
+      REAL               RDUM( 1 ), RESULT( NTESTS )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -131,7 +235,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -148,7 +252,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'GB'
       NRUN = 0
       NFAIL = 0
@@ -172,7 +276,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 160 IN = 1, NN
+      DO 150 IN = 1, NN
          N = NVAL( IN )
          LDB = MAX( N, 1 )
          XTYPE = 'N'
@@ -187,7 +291,7 @@
          IF( N.LE.0 )
      $      NIMAT = 1
 *
-         DO 150 IKL = 1, NKL
+         DO 140 IKL = 1, NKL
 *
 *           Do for KL = 0, N-1, (3N-1)/4, and (N+1)/4. This order makes
 *           it easier to skip redundant values for small values of N.
@@ -201,7 +305,7 @@
             ELSE IF( IKL.EQ.4 ) THEN
                KL = ( N+1 ) / 4
             END IF
-            DO 140 IKU = 1, NKU
+            DO 130 IKU = 1, NKU
 *
 *              Do for KU = 0, N-1, (3N-1)/4, and (N+1)/4. This order
 *              makes it easier to skip redundant values for small
@@ -235,21 +339,21 @@
      $                  N*( 2*KL+KU+1 )
                      NERRS = NERRS + 1
                   END IF
-                  GO TO 140
+                  GO TO 130
                END IF
 *
-               DO 130 IMAT = 1, NIMAT
+               DO 120 IMAT = 1, NIMAT
 *
 *                 Do the tests only if DOTYPE( IMAT ) is true.
 *
                   IF( .NOT.DOTYPE( IMAT ) )
-     $               GO TO 130
+     $               GO TO 120
 *
 *                 Skip types 2, 3, or 4 if the matrix is too small.
 *
                   ZEROT = IMAT.GE.2 .AND. IMAT.LE.4
                   IF( ZEROT .AND. N.LT.IMAT-1 )
-     $               GO TO 130
+     $               GO TO 120
 *
 *                 Set up parameters with CLATB4 and generate a
 *                 test matrix with CLATMS.
@@ -268,7 +372,7 @@
                   IF( INFO.NE.0 ) THEN
                      CALL ALAERH( PATH, 'CLATMS', INFO, 0, ' ', N, N,
      $                            KL, KU, -1, IMAT, NFAIL, NERRS, NOUT )
-                     GO TO 130
+                     GO TO 120
                   END IF
 *
 *                 For types 2, 3, and 4, zero one or more columns of
@@ -305,7 +409,7 @@
 *
                   CALL CLACPY( 'Full', KL+KU+1, N, A, LDA, ASAV, LDA )
 *
-                  DO 120 IEQUED = 1, 4
+                  DO 110 IEQUED = 1, 4
                      EQUED = EQUEDS( IEQUED )
                      IF( IEQUED.EQ.1 ) THEN
                         NFACT = 3
@@ -313,7 +417,7 @@
                         NFACT = 1
                      END IF
 *
-                     DO 110 IFACT = 1, NFACT
+                     DO 100 IFACT = 1, NFACT
                         FACT = FACTS( IFACT )
                         PREFAC = LSAME( FACT, 'F' )
                         NOFACT = LSAME( FACT, 'N' )
@@ -321,7 +425,7 @@
 *
                         IF( ZEROT ) THEN
                            IF( PREFAC )
-     $                        GO TO 110
+     $                        GO TO 100
                            RCONDO = ZERO
                            RCONDI = ZERO
 *
@@ -413,9 +517,8 @@
                               RCONDI = ( ONE / ANORMI ) / AINVNM
                            END IF
                         END IF
-   50                   CONTINUE
 *
-                        DO 100 ITRAN = 1, NTRAN
+                        DO 90 ITRAN = 1, NTRAN
 *
 *                          Do for each value of TRANS.
 *
@@ -495,7 +598,7 @@
 *                             Print information about the tests that did
 *                             not pass the threshold.
 *
-                              DO 60 K = 1, NT
+                              DO 50 K = 1, NT
                                  IF( RESULT( K ).GE.THRESH ) THEN
                                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                                 CALL ALADHD( NOUT, PATH )
@@ -503,7 +606,7 @@
      $                                 N, KL, KU, IMAT, K, RESULT( K )
                                     NFAIL = NFAIL + 1
                                  END IF
-   60                         CONTINUE
+   50                         CONTINUE
                               NRUN = NRUN + NT
                            END IF
 *
@@ -545,19 +648,19 @@
 *                          Compare RWORK(2*NRHS+1) from CGBSVX with the
 *                          computed reciprocal pivot growth RPVGRW
 *
-                           IF( INFO.NE.0 ) THEN
+                           IF( INFO.NE.0 .AND. INFO.LE.N) THEN
                               ANRMPV = ZERO
-                              DO 80 J = 1, INFO
-                                 DO 70 I = MAX( KU+2-J, 1 ),
+                              DO 70 J = 1, INFO
+                                 DO 60 I = MAX( KU+2-J, 1 ),
      $                                   MIN( N+KU+1-J, KL+KU+1 )
                                     ANRMPV = MAX( ANRMPV,
      $                                       ABS( A( I+( J-1 )*LDA ) ) )
-   70                            CONTINUE
-   80                         CONTINUE
+   60                            CONTINUE
+   70                         CONTINUE
                               RPVGRW = CLANTB( 'M', 'U', 'N', INFO,
      $                                 MIN( INFO-1, KL+KU ),
      $                                 AFB( MAX( 1, KL+KU+2-INFO ) ),
-     $                                 LDAFB, WORK )
+     $                                 LDAFB, RDUM )
                               IF( RPVGRW.EQ.ZERO ) THEN
                                  RPVGRW = ONE
                               ELSE
@@ -565,12 +668,12 @@
                               END IF
                            ELSE
                               RPVGRW = CLANTB( 'M', 'U', 'N', N, KL+KU,
-     $                                 AFB, LDAFB, WORK )
+     $                                 AFB, LDAFB, RDUM )
                               IF( RPVGRW.EQ.ZERO ) THEN
                                  RPVGRW = ONE
                               ELSE
                                  RPVGRW = CLANGB( 'M', N, KL, KU, A,
-     $                                    LDA, WORK ) / RPVGRW
+     $                                    LDA, RDUM ) / RPVGRW
                               END IF
                            END IF
                            RESULT( 7 ) = ABS( RPVGRW-RWORK( 2*NRHS+1 ) )
@@ -638,7 +741,7 @@
 *                          not pass the threshold.
 *
                            IF( .NOT.TRFCON ) THEN
-                              DO 90 K = K1, NTESTS
+                              DO 80 K = K1, NTESTS
                                  IF( RESULT( K ).GE.THRESH ) THEN
                                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                                 CALL ALADHD( NOUT, PATH )
@@ -654,8 +757,8 @@
                                     END IF
                                     NFAIL = NFAIL + 1
                                  END IF
-   90                         CONTINUE
-                              NRUN = NRUN + 7 - K1
+   80                         CONTINUE
+                              NRUN = NRUN + NTESTS - K1 + 1
                            ELSE
                               IF( RESULT( 1 ).GE.THRESH .AND. .NOT.
      $                            PREFAC ) THEN
@@ -704,13 +807,13 @@
                                  NRUN = NRUN + 1
                               END IF
                            END IF
-  100                   CONTINUE
-  110                CONTINUE
-  120             CONTINUE
-  130          CONTINUE
-  140       CONTINUE
-  150    CONTINUE
-  160 CONTINUE
+   90                   CONTINUE
+  100                CONTINUE
+  110             CONTINUE
+  120          CONTINUE
+  130       CONTINUE
+  140    CONTINUE
+  150 CONTINUE
 *
 *     Print a summary of the results.
 *
@@ -722,11 +825,11 @@
  9998 FORMAT( ' *** In CDRVGB, LAFB=', I5, ' is too small for N=', I5,
      $      ', KU=', I5, ', KL=', I5, /
      $      ' ==> Increase LAFB to at least ', I5 )
- 9997 FORMAT( 1X, A6, ', N=', I5, ', KL=', I5, ', KU=', I5, ', type ',
+ 9997 FORMAT( 1X, A, ', N=', I5, ', KL=', I5, ', KU=', I5, ', type ',
      $      I1, ', test(', I1, ')=', G12.5 )
- 9996 FORMAT( 1X, A6, '( ''', A1, ''',''', A1, ''',', I5, ',', I5, ',',
+ 9996 FORMAT( 1X, A, '( ''', A1, ''',''', A1, ''',', I5, ',', I5, ',',
      $      I5, ',...), type ', I1, ', test(', I1, ')=', G12.5 )
- 9995 FORMAT( 1X, A6, '( ''', A1, ''',''', A1, ''',', I5, ',', I5, ',',
+ 9995 FORMAT( 1X, A, '( ''', A1, ''',''', A1, ''',', I5, ',', I5, ',',
      $      I5, ',...), EQUED=''', A1, ''', type ', I1, ', test(', I1,
      $      ')=', G12.5 )
 *
