@@ -1,11 +1,173 @@
+*> \brief \b CDRVGE
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at 
+*            http://www.netlib.org/lapack/explore-html/ 
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE CDRVGE( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
+*                          A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
+*                          RWORK, IWORK, NOUT )
+* 
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NMAX, NN, NOUT, NRHS
+*       REAL               THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            IWORK( * ), NVAL( * )
+*       REAL               RWORK( * ), S( * )
+*       COMPLEX            A( * ), AFAC( * ), ASAV( * ), B( * ),
+*      $                   BSAV( * ), WORK( * ), X( * ), XACT( * )
+*       ..
+*  
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> CDRVGE tests the driver routines CGESV and -SVX.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix column dimension N.
+*> \endverbatim
+*>
+*> \param[in] NRHS
+*> \verbatim
+*>          NRHS is INTEGER
+*>          The number of right hand side vectors to be generated for
+*>          each linear system.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is REAL
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The maximum value permitted for N, used in dimensioning the
+*>          work arrays.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is COMPLEX array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AFAC
+*> \verbatim
+*>          AFAC is COMPLEX array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] ASAV
+*> \verbatim
+*>          ASAV is COMPLEX array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] BSAV
+*> \verbatim
+*>          BSAV is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is COMPLEX array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is REAL array, dimension (2*NMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is COMPLEX array, dimension
+*>                      (NMAX*max(3,NRHS))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is REAL array, dimension (2*NRHS+NMAX)
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee 
+*> \author Univ. of California Berkeley 
+*> \author Univ. of Colorado Denver 
+*> \author NAG Ltd. 
+*
+*> \date November 2015
+*
+*> \ingroup complex_lin
+*
+*  =====================================================================
       SUBROUTINE CDRVGE( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2015
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -20,67 +182,6 @@
      $                   BSAV( * ), WORK( * ), X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  CDRVGE tests the driver routines CGESV and -SVX.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix column dimension N.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) REAL
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The maximum value permitted for N, used in dimensioning the
-*          work arrays.
-*
-*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX)
-*
-*  AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX)
-*
-*  ASAV    (workspace) COMPLEX array, dimension (NMAX*NMAX)
-*
-*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  BSAV    (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  S       (workspace) REAL array, dimension (2*NMAX)
-*
-*  WORK    (workspace) COMPLEX array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) REAL array, dimension (2*NRHS+NMAX)
-*
-*  IWORK   (workspace) INTEGER array, dimension (NMAX)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -107,7 +208,7 @@
 *     .. Local Arrays ..
       CHARACTER          EQUEDS( 4 ), FACTS( 3 ), TRANSS( NTRAN )
       INTEGER            ISEED( 4 ), ISEEDY( 4 )
-      REAL               RESULT( NTESTS )
+      REAL               RDUM( 1 ), RESULT( NTESTS )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -125,7 +226,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -142,7 +243,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'GE'
       NRUN = 0
       NFAIL = 0
@@ -166,7 +267,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 100 IN = 1, NN
+      DO 90 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          XTYPE = 'N'
@@ -174,18 +275,18 @@
          IF( N.LE.0 )
      $      NIMAT = 1
 *
-         DO 90 IMAT = 1, NIMAT
+         DO 80 IMAT = 1, NIMAT
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 90
+     $         GO TO 80
 *
 *           Skip types 5, 6, or 7 if the matrix size is too small.
 *
             ZEROT = IMAT.GE.5 .AND. IMAT.LE.7
             IF( ZEROT .AND. N.LT.IMAT-4 )
-     $         GO TO 90
+     $         GO TO 80
 *
 *           Set up parameters with CLATB4 and generate a test matrix
 *           with CLATMS.
@@ -204,7 +305,7 @@
             IF( INFO.NE.0 ) THEN
                CALL ALAERH( PATH, 'CLATMS', INFO, 0, ' ', N, N, -1, -1,
      $                      -1, IMAT, NFAIL, NERRS, NOUT )
-               GO TO 90
+               GO TO 80
             END IF
 *
 *           For types 5-7, zero one or more columns of the matrix to
@@ -235,7 +336,7 @@
 *
             CALL CLACPY( 'Full', N, N, A, LDA, ASAV, LDA )
 *
-            DO 80 IEQUED = 1, 4
+            DO 70 IEQUED = 1, 4
                EQUED = EQUEDS( IEQUED )
                IF( IEQUED.EQ.1 ) THEN
                   NFACT = 3
@@ -243,7 +344,7 @@
                   NFACT = 1
                END IF
 *
-               DO 70 IFACT = 1, NFACT
+               DO 60 IFACT = 1, NFACT
                   FACT = FACTS( IFACT )
                   PREFAC = LSAME( FACT, 'F' )
                   NOFACT = LSAME( FACT, 'N' )
@@ -251,7 +352,7 @@
 *
                   IF( ZEROT ) THEN
                      IF( PREFAC )
-     $                  GO TO 70
+     $                  GO TO 60
                      RCONDO = ZERO
                      RCONDI = ZERO
 *
@@ -304,12 +405,14 @@
 *
 *                    Factor the matrix A.
 *
+                     SRNAMT = 'CGETRF'
                      CALL CGETRF( N, N, AFAC, LDA, IWORK, INFO )
 *
 *                    Form the inverse of A.
 *
                      CALL CLACPY( 'Full', N, N, AFAC, LDA, A, LDA )
                      LWORK = NMAX*MAX( 3, NRHS )
+                     SRNAMT = 'CGETRI'
                      CALL CGETRI( N, A, LDA, IWORK, WORK, LWORK, INFO )
 *
 *                    Compute the 1-norm condition number of A.
@@ -330,9 +433,8 @@
                         RCONDI = ( ONE / ANORMI ) / AINVNM
                      END IF
                   END IF
-   30             CONTINUE
 *
-                  DO 60 ITRAN = 1, NTRAN
+                  DO 50 ITRAN = 1, NTRAN
 *
 *                    Do for each value of TRANS.
 *
@@ -403,7 +505,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 40 K = 1, NT
+                        DO 30 K = 1, NT
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -411,7 +513,7 @@
      $                           IMAT, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   40                   CONTINUE
+   30                   CONTINUE
                         NRUN = NRUN + NT
                      END IF
 *
@@ -451,22 +553,22 @@
 *                    Compare RWORK(2*NRHS+1) from CGESVX with the
 *                    computed reciprocal pivot growth factor RPVGRW
 *
-                     IF( INFO.NE.0 ) THEN
+                     IF( INFO.NE.0 .AND. INFO.LE.N) THEN
                         RPVGRW = CLANTR( 'M', 'U', 'N', INFO, INFO,
-     $                           AFAC, LDA, WORK )
+     $                           AFAC, LDA, RDUM )
                         IF( RPVGRW.EQ.ZERO ) THEN
                            RPVGRW = ONE
                         ELSE
                            RPVGRW = CLANGE( 'M', N, INFO, A, LDA,
-     $                              WORK ) / RPVGRW
+     $                              RDUM ) / RPVGRW
                         END IF
                      ELSE
                         RPVGRW = CLANTR( 'M', 'U', 'N', N, N, AFAC, LDA,
-     $                           WORK )
+     $                           RDUM )
                         IF( RPVGRW.EQ.ZERO ) THEN
                            RPVGRW = ONE
                         ELSE
-                           RPVGRW = CLANGE( 'M', N, N, A, LDA, WORK ) /
+                           RPVGRW = CLANGE( 'M', N, N, A, LDA, RDUM ) /
      $                              RPVGRW
                         END IF
                      END IF
@@ -517,7 +619,7 @@
 *                       refinement.
 *
                         CALL CGET07( TRANS, N, NRHS, ASAV, LDA, B, LDA,
-     $                               X, LDA, XACT, LDA, RWORK,
+     $                               X, LDA, XACT, LDA, RWORK, .TRUE.,
      $                               RWORK( NRHS+1 ), RESULT( 4 ) )
                      ELSE
                         TRFCON = .TRUE.
@@ -532,7 +634,7 @@
 *                    the threshold.
 *
                      IF( .NOT.TRFCON ) THEN
-                        DO 50 K = K1, NTESTS
+                        DO 40 K = K1, NTESTS
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -546,8 +648,8 @@
                               END IF
                               NFAIL = NFAIL + 1
                            END IF
-   50                   CONTINUE
-                        NRUN = NRUN + 7 - K1
+   40                   CONTINUE
+                        NRUN = NRUN + NTESTS - K1 + 1
                      ELSE
                         IF( RESULT( 1 ).GE.THRESH .AND. .NOT.PREFAC )
      $                       THEN
@@ -592,21 +694,21 @@
 *
                      END IF
 *
-   60             CONTINUE
-   70          CONTINUE
-   80       CONTINUE
-   90    CONTINUE
-  100 CONTINUE
+   50             CONTINUE
+   60          CONTINUE
+   70       CONTINUE
+   80    CONTINUE
+   90 CONTINUE
 *
 *     Print a summary of the results.
 *
       CALL ALASVM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( 1X, A6, ', N =', I5, ', type ', I2, ', test(', I2, ') =',
+ 9999 FORMAT( 1X, A, ', N =', I5, ', type ', I2, ', test(', I2, ') =',
      $      G12.5 )
- 9998 FORMAT( 1X, A6, ', FACT=''', A1, ''', TRANS=''', A1, ''', N=', I5,
+ 9998 FORMAT( 1X, A, ', FACT=''', A1, ''', TRANS=''', A1, ''', N=', I5,
      $      ', type ', I2, ', test(', I1, ')=', G12.5 )
- 9997 FORMAT( 1X, A6, ', FACT=''', A1, ''', TRANS=''', A1, ''', N=', I5,
+ 9997 FORMAT( 1X, A, ', FACT=''', A1, ''', TRANS=''', A1, ''', N=', I5,
      $      ', EQUED=''', A1, ''', type ', I2, ', test(', I1, ')=',
      $      G12.5 )
       RETURN
